/*
    Copyright (c) 2008-2013 NetAllied Systems GmbH

    This file is part of COLLADASaxFrameworkLoader.

    Licensed under the MIT Open Source License,
    for details please see LICENSE file or the website
    http://www.opensource.org/licenses/mit-license.php
*/

#include "COLLADASaxFWLStableHeaders.h"
#include "COLLADASaxFWLColladaParserAutoGen14Private.h"


namespace COLLADASaxFWL14
{


//---------------------------------------------------------------------
void ColladaParserAutoGen14Private::initNameMap()
{
mHashNameMap[HASH_NAMESPACE_COLLADA] = NAME_NAMESPACE_COLLADA;
mHashNameMap[HASH_NAMESPACE_http___www_w3_org_2001_XMLSchema] = NAME_NAMESPACE_http___www_w3_org_2001_XMLSchema;
mHashNameMap[HASH_NAMESPACE_http___www_w3_org_XML_1998_namespace] = NAME_NAMESPACE_http___www_w3_org_XML_1998_namespace;
mHashNameMap[HASH_ATTRIBUTE_base] = NAME_ATTRIBUTE_base;
mHashNameMap[HASH_ATTRIBUTE_body] = NAME_ATTRIBUTE_body;
mHashNameMap[HASH_ATTRIBUTE_camera_node] = NAME_ATTRIBUTE_camera_node;
mHashNameMap[HASH_ATTRIBUTE_closed] = NAME_ATTRIBUTE_closed;
mHashNameMap[HASH_ATTRIBUTE_constraint] = NAME_ATTRIBUTE_constraint;
mHashNameMap[HASH_ATTRIBUTE_convex_hull_of] = NAME_ATTRIBUTE_convex_hull_of;
mHashNameMap[HASH_ATTRIBUTE_count] = NAME_ATTRIBUTE_count;
mHashNameMap[HASH_ATTRIBUTE_depth] = NAME_ATTRIBUTE_depth;
mHashNameMap[HASH_ATTRIBUTE_digits] = NAME_ATTRIBUTE_digits;
mHashNameMap[HASH_ATTRIBUTE_end] = NAME_ATTRIBUTE_end;
mHashNameMap[HASH_ATTRIBUTE_face] = NAME_ATTRIBUTE_face;
mHashNameMap[HASH_ATTRIBUTE_format] = NAME_ATTRIBUTE_format;
mHashNameMap[HASH_ATTRIBUTE_height] = NAME_ATTRIBUTE_height;
mHashNameMap[HASH_ATTRIBUTE_id] = NAME_ATTRIBUTE_id;
mHashNameMap[HASH_ATTRIBUTE_index] = NAME_ATTRIBUTE_index;
mHashNameMap[HASH_ATTRIBUTE_input_semantic] = NAME_ATTRIBUTE_input_semantic;
mHashNameMap[HASH_ATTRIBUTE_input_set] = NAME_ATTRIBUTE_input_set;
mHashNameMap[HASH_ATTRIBUTE_layer] = NAME_ATTRIBUTE_layer;
mHashNameMap[HASH_ATTRIBUTE_length] = NAME_ATTRIBUTE_length;
mHashNameMap[HASH_ATTRIBUTE_magnitude] = NAME_ATTRIBUTE_magnitude;
mHashNameMap[HASH_ATTRIBUTE_material] = NAME_ATTRIBUTE_material;
mHashNameMap[HASH_ATTRIBUTE_maxInclusive] = NAME_ATTRIBUTE_maxInclusive;
mHashNameMap[HASH_ATTRIBUTE_meter] = NAME_ATTRIBUTE_meter;
mHashNameMap[HASH_ATTRIBUTE_method] = NAME_ATTRIBUTE_method;
mHashNameMap[HASH_ATTRIBUTE_minInclusive] = NAME_ATTRIBUTE_minInclusive;
mHashNameMap[HASH_ATTRIBUTE_mip] = NAME_ATTRIBUTE_mip;
mHashNameMap[HASH_ATTRIBUTE_name] = NAME_ATTRIBUTE_name;
mHashNameMap[HASH_ATTRIBUTE_offset] = NAME_ATTRIBUTE_offset;
mHashNameMap[HASH_ATTRIBUTE_opaque] = NAME_ATTRIBUTE_opaque;
mHashNameMap[HASH_ATTRIBUTE_operand] = NAME_ATTRIBUTE_operand;
mHashNameMap[HASH_ATTRIBUTE_operator] = NAME_ATTRIBUTE_operator;
mHashNameMap[HASH_ATTRIBUTE_param] = NAME_ATTRIBUTE_param;
mHashNameMap[HASH_ATTRIBUTE_parent] = NAME_ATTRIBUTE_parent;
mHashNameMap[HASH_ATTRIBUTE_platform] = NAME_ATTRIBUTE_platform;
mHashNameMap[HASH_ATTRIBUTE_profile] = NAME_ATTRIBUTE_profile;
mHashNameMap[HASH_ATTRIBUTE_program] = NAME_ATTRIBUTE_program;
mHashNameMap[HASH_ATTRIBUTE_ref] = NAME_ATTRIBUTE_ref;
mHashNameMap[HASH_ATTRIBUTE_rigid_body] = NAME_ATTRIBUTE_rigid_body;
mHashNameMap[HASH_ATTRIBUTE_scale] = NAME_ATTRIBUTE_scale;
mHashNameMap[HASH_ATTRIBUTE_semantic] = NAME_ATTRIBUTE_semantic;
mHashNameMap[HASH_ATTRIBUTE_set] = NAME_ATTRIBUTE_set;
mHashNameMap[HASH_ATTRIBUTE_sid] = NAME_ATTRIBUTE_sid;
mHashNameMap[HASH_ATTRIBUTE_slice] = NAME_ATTRIBUTE_slice;
mHashNameMap[HASH_ATTRIBUTE_source] = NAME_ATTRIBUTE_source;
mHashNameMap[HASH_ATTRIBUTE_stage] = NAME_ATTRIBUTE_stage;
mHashNameMap[HASH_ATTRIBUTE_start] = NAME_ATTRIBUTE_start;
mHashNameMap[HASH_ATTRIBUTE_stride] = NAME_ATTRIBUTE_stride;
mHashNameMap[HASH_ATTRIBUTE_symbol] = NAME_ATTRIBUTE_symbol;
mHashNameMap[HASH_ATTRIBUTE_target] = NAME_ATTRIBUTE_target;
mHashNameMap[HASH_ATTRIBUTE_texcoord] = NAME_ATTRIBUTE_texcoord;
mHashNameMap[HASH_ATTRIBUTE_texture] = NAME_ATTRIBUTE_texture;
mHashNameMap[HASH_ATTRIBUTE_type] = NAME_ATTRIBUTE_type;
mHashNameMap[HASH_ATTRIBUTE_unit] = NAME_ATTRIBUTE_unit;
mHashNameMap[HASH_ATTRIBUTE_url] = NAME_ATTRIBUTE_url;
mHashNameMap[HASH_ATTRIBUTE_value] = NAME_ATTRIBUTE_value;
mHashNameMap[HASH_ATTRIBUTE_version] = NAME_ATTRIBUTE_version;
mHashNameMap[HASH_ATTRIBUTE_width] = NAME_ATTRIBUTE_width;
mHashNameMap[HASH_ATTRIBUTE_xmlns] = NAME_ATTRIBUTE_xmlns;
mHashNameMap[HASH_ELEMENT_ACCESSOR] = NAME_ELEMENT_ACCESSOR;
mHashNameMap[HASH_ELEMENT_ALL] = NAME_ELEMENT_ALL;
mHashNameMap[HASH_ELEMENT_ALPHA] = NAME_ELEMENT_ALPHA;
mHashNameMap[HASH_ELEMENT_ALPHA_FUNC] = NAME_ELEMENT_ALPHA_FUNC;
mHashNameMap[HASH_ELEMENT_ALPHA_TEST_ENABLE] = NAME_ELEMENT_ALPHA_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_ALPHA____GLES_TEXCOMBINER_COMMANDALPHA_TYPE] = NAME_ELEMENT_ALPHA____GLES_TEXCOMBINER_COMMANDALPHA_TYPE;
mHashNameMap[HASH_ELEMENT_AMBIENT] = NAME_ELEMENT_AMBIENT;
mHashNameMap[HASH_ELEMENT_AMBIENT____COMMON_COLOR_OR_TEXTURE_TYPE] = NAME_ELEMENT_AMBIENT____COMMON_COLOR_OR_TEXTURE_TYPE;
mHashNameMap[HASH_ELEMENT_ANGULAR] = NAME_ELEMENT_ANGULAR;
mHashNameMap[HASH_ELEMENT_ANGULAR_VELOCITY] = NAME_ELEMENT_ANGULAR_VELOCITY;
mHashNameMap[HASH_ELEMENT_ANIMATION] = NAME_ELEMENT_ANIMATION;
mHashNameMap[HASH_ELEMENT_ANIMATION_CLIP] = NAME_ELEMENT_ANIMATION_CLIP;
mHashNameMap[HASH_ELEMENT_ANIMATION__SOURCE__TECHNIQUE_COMMON] = NAME_ELEMENT_ANIMATION__SOURCE__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_ANNOTATE] = NAME_ELEMENT_ANNOTATE;
mHashNameMap[HASH_ELEMENT_ARGUMENT] = NAME_ELEMENT_ARGUMENT;
mHashNameMap[HASH_ELEMENT_ARGUMENT____GLES_TEXCOMBINER_ARGUMENTALPHA_TYPE] = NAME_ELEMENT_ARGUMENT____GLES_TEXCOMBINER_ARGUMENTALPHA_TYPE;
mHashNameMap[HASH_ELEMENT_ARGUMENT____GLES_TEXCOMBINER_ARGUMENTRGB_TYPE] = NAME_ELEMENT_ARGUMENT____GLES_TEXCOMBINER_ARGUMENTRGB_TYPE;
mHashNameMap[HASH_ELEMENT_ARRAY] = NAME_ELEMENT_ARRAY;
mHashNameMap[HASH_ELEMENT_ARRAY____CG_NEWARRAY_TYPE] = NAME_ELEMENT_ARRAY____CG_NEWARRAY_TYPE;
mHashNameMap[HASH_ELEMENT_ARRAY____CG_SETARRAY_TYPE] = NAME_ELEMENT_ARRAY____CG_SETARRAY_TYPE;
mHashNameMap[HASH_ELEMENT_ARRAY____GLSL_NEWARRAY_TYPE] = NAME_ELEMENT_ARRAY____GLSL_NEWARRAY_TYPE;
mHashNameMap[HASH_ELEMENT_ARRAY____GLSL_SETARRAY_TYPE] = NAME_ELEMENT_ARRAY____GLSL_SETARRAY_TYPE;
mHashNameMap[HASH_ELEMENT_ASPECT_RATIO] = NAME_ELEMENT_ASPECT_RATIO;
mHashNameMap[HASH_ELEMENT_ASSET] = NAME_ELEMENT_ASSET;
mHashNameMap[HASH_ELEMENT_ATTACHMENT] = NAME_ELEMENT_ATTACHMENT;
mHashNameMap[HASH_ELEMENT_AUTHOR] = NAME_ELEMENT_AUTHOR;
mHashNameMap[HASH_ELEMENT_AUTHORING_TOOL] = NAME_ELEMENT_AUTHORING_TOOL;
mHashNameMap[HASH_ELEMENT_AUTO_NORMAL_ENABLE] = NAME_ELEMENT_AUTO_NORMAL_ENABLE;
mHashNameMap[HASH_ELEMENT_BACK] = NAME_ELEMENT_BACK;
mHashNameMap[HASH_ELEMENT_BIND] = NAME_ELEMENT_BIND;
mHashNameMap[HASH_ELEMENT_BIND_MATERIAL] = NAME_ELEMENT_BIND_MATERIAL;
mHashNameMap[HASH_ELEMENT_BIND_MATERIAL__TECHNIQUE_COMMON] = NAME_ELEMENT_BIND_MATERIAL__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_BIND_SHAPE_MATRIX] = NAME_ELEMENT_BIND_SHAPE_MATRIX;
mHashNameMap[HASH_ELEMENT_BIND_VERTEX_INPUT] = NAME_ELEMENT_BIND_VERTEX_INPUT;
mHashNameMap[HASH_ELEMENT_BLEND_COLOR] = NAME_ELEMENT_BLEND_COLOR;
mHashNameMap[HASH_ELEMENT_BLEND_ENABLE] = NAME_ELEMENT_BLEND_ENABLE;
mHashNameMap[HASH_ELEMENT_BLEND_EQUATION] = NAME_ELEMENT_BLEND_EQUATION;
mHashNameMap[HASH_ELEMENT_BLEND_EQUATION_SEPARATE] = NAME_ELEMENT_BLEND_EQUATION_SEPARATE;
mHashNameMap[HASH_ELEMENT_BLEND_EQUATION_SEPARATE__ALPHA] = NAME_ELEMENT_BLEND_EQUATION_SEPARATE__ALPHA;
mHashNameMap[HASH_ELEMENT_BLEND_FUNC] = NAME_ELEMENT_BLEND_FUNC;
mHashNameMap[HASH_ELEMENT_BLEND_FUNC_SEPARATE] = NAME_ELEMENT_BLEND_FUNC_SEPARATE;
mHashNameMap[HASH_ELEMENT_BLINN] = NAME_ELEMENT_BLINN;
mHashNameMap[HASH_ELEMENT_BOOL] = NAME_ELEMENT_BOOL;
mHashNameMap[HASH_ELEMENT_BOOL1] = NAME_ELEMENT_BOOL1;
mHashNameMap[HASH_ELEMENT_BOOL1X1] = NAME_ELEMENT_BOOL1X1;
mHashNameMap[HASH_ELEMENT_BOOL1X2] = NAME_ELEMENT_BOOL1X2;
mHashNameMap[HASH_ELEMENT_BOOL1X3] = NAME_ELEMENT_BOOL1X3;
mHashNameMap[HASH_ELEMENT_BOOL1X4] = NAME_ELEMENT_BOOL1X4;
mHashNameMap[HASH_ELEMENT_BOOL2] = NAME_ELEMENT_BOOL2;
mHashNameMap[HASH_ELEMENT_BOOL2X1] = NAME_ELEMENT_BOOL2X1;
mHashNameMap[HASH_ELEMENT_BOOL2X2] = NAME_ELEMENT_BOOL2X2;
mHashNameMap[HASH_ELEMENT_BOOL2X3] = NAME_ELEMENT_BOOL2X3;
mHashNameMap[HASH_ELEMENT_BOOL2X4] = NAME_ELEMENT_BOOL2X4;
mHashNameMap[HASH_ELEMENT_BOOL2____BOOL2] = NAME_ELEMENT_BOOL2____BOOL2;
mHashNameMap[HASH_ELEMENT_BOOL2____CG_BOOL2] = NAME_ELEMENT_BOOL2____CG_BOOL2;
mHashNameMap[HASH_ELEMENT_BOOL2____GLSL_BOOL2] = NAME_ELEMENT_BOOL2____GLSL_BOOL2;
mHashNameMap[HASH_ELEMENT_BOOL3] = NAME_ELEMENT_BOOL3;
mHashNameMap[HASH_ELEMENT_BOOL3X1] = NAME_ELEMENT_BOOL3X1;
mHashNameMap[HASH_ELEMENT_BOOL3X2] = NAME_ELEMENT_BOOL3X2;
mHashNameMap[HASH_ELEMENT_BOOL3X3] = NAME_ELEMENT_BOOL3X3;
mHashNameMap[HASH_ELEMENT_BOOL3X4] = NAME_ELEMENT_BOOL3X4;
mHashNameMap[HASH_ELEMENT_BOOL3____BOOL3] = NAME_ELEMENT_BOOL3____BOOL3;
mHashNameMap[HASH_ELEMENT_BOOL3____CG_BOOL3] = NAME_ELEMENT_BOOL3____CG_BOOL3;
mHashNameMap[HASH_ELEMENT_BOOL3____GLSL_BOOL3] = NAME_ELEMENT_BOOL3____GLSL_BOOL3;
mHashNameMap[HASH_ELEMENT_BOOL4] = NAME_ELEMENT_BOOL4;
mHashNameMap[HASH_ELEMENT_BOOL4X1] = NAME_ELEMENT_BOOL4X1;
mHashNameMap[HASH_ELEMENT_BOOL4X2] = NAME_ELEMENT_BOOL4X2;
mHashNameMap[HASH_ELEMENT_BOOL4X3] = NAME_ELEMENT_BOOL4X3;
mHashNameMap[HASH_ELEMENT_BOOL4X4] = NAME_ELEMENT_BOOL4X4;
mHashNameMap[HASH_ELEMENT_BOOL4____BOOL4] = NAME_ELEMENT_BOOL4____BOOL4;
mHashNameMap[HASH_ELEMENT_BOOL4____CG_BOOL4] = NAME_ELEMENT_BOOL4____CG_BOOL4;
mHashNameMap[HASH_ELEMENT_BOOL4____GLSL_BOOL4] = NAME_ELEMENT_BOOL4____GLSL_BOOL4;
mHashNameMap[HASH_ELEMENT_BOOL_ARRAY] = NAME_ELEMENT_BOOL_ARRAY;
mHashNameMap[HASH_ELEMENT_BOOL____BOOL] = NAME_ELEMENT_BOOL____BOOL;
mHashNameMap[HASH_ELEMENT_BOOL____CG_BOOL] = NAME_ELEMENT_BOOL____CG_BOOL;
mHashNameMap[HASH_ELEMENT_BOOL____GLSL_BOOL] = NAME_ELEMENT_BOOL____GLSL_BOOL;
mHashNameMap[HASH_ELEMENT_BORDER_COLOR] = NAME_ELEMENT_BORDER_COLOR;
mHashNameMap[HASH_ELEMENT_BOX] = NAME_ELEMENT_BOX;
mHashNameMap[HASH_ELEMENT_CAMERA] = NAME_ELEMENT_CAMERA;
mHashNameMap[HASH_ELEMENT_CAPSULE] = NAME_ELEMENT_CAPSULE;
mHashNameMap[HASH_ELEMENT_CG_SURFACE_TYPE____GENERATOR] = NAME_ELEMENT_CG_SURFACE_TYPE____GENERATOR;
mHashNameMap[HASH_ELEMENT_CHANNEL] = NAME_ELEMENT_CHANNEL;
mHashNameMap[HASH_ELEMENT_CHANNELS] = NAME_ELEMENT_CHANNELS;
mHashNameMap[HASH_ELEMENT_CLEAR_COLOR] = NAME_ELEMENT_CLEAR_COLOR;
mHashNameMap[HASH_ELEMENT_CLEAR_DEPTH] = NAME_ELEMENT_CLEAR_DEPTH;
mHashNameMap[HASH_ELEMENT_CLEAR_STENCIL] = NAME_ELEMENT_CLEAR_STENCIL;
mHashNameMap[HASH_ELEMENT_CLIP_PLANE] = NAME_ELEMENT_CLIP_PLANE;
mHashNameMap[HASH_ELEMENT_CLIP_PLANE_ENABLE] = NAME_ELEMENT_CLIP_PLANE_ENABLE;
mHashNameMap[HASH_ELEMENT_CODE] = NAME_ELEMENT_CODE;
mHashNameMap[HASH_ELEMENT_COLLADA] = NAME_ELEMENT_COLLADA;
mHashNameMap[HASH_ELEMENT_COLOR] = NAME_ELEMENT_COLOR;
mHashNameMap[HASH_ELEMENT_COLOR_CLEAR] = NAME_ELEMENT_COLOR_CLEAR;
mHashNameMap[HASH_ELEMENT_COLOR_CLEAR____FX_CLEARCOLOR_COMMON] = NAME_ELEMENT_COLOR_CLEAR____FX_CLEARCOLOR_COMMON;
mHashNameMap[HASH_ELEMENT_COLOR_CLEAR____FX_COLOR_COMMON] = NAME_ELEMENT_COLOR_CLEAR____FX_COLOR_COMMON;
mHashNameMap[HASH_ELEMENT_COLOR_LOGIC_OP_ENABLE] = NAME_ELEMENT_COLOR_LOGIC_OP_ENABLE;
mHashNameMap[HASH_ELEMENT_COLOR_MASK] = NAME_ELEMENT_COLOR_MASK;
mHashNameMap[HASH_ELEMENT_COLOR_MATERIAL] = NAME_ELEMENT_COLOR_MATERIAL;
mHashNameMap[HASH_ELEMENT_COLOR_MATERIAL_ENABLE] = NAME_ELEMENT_COLOR_MATERIAL_ENABLE;
mHashNameMap[HASH_ELEMENT_COLOR_MATERIAL__FACE] = NAME_ELEMENT_COLOR_MATERIAL__FACE;
mHashNameMap[HASH_ELEMENT_COLOR_MATERIAL__MODE] = NAME_ELEMENT_COLOR_MATERIAL__MODE;
mHashNameMap[HASH_ELEMENT_COLOR_TARGET] = NAME_ELEMENT_COLOR_TARGET;
mHashNameMap[HASH_ELEMENT_COLOR_TARGET____FX_COLORTARGET_COMMON] = NAME_ELEMENT_COLOR_TARGET____FX_COLORTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_COLOR_TARGET____GLES_RENDERTARGET_COMMON] = NAME_ELEMENT_COLOR_TARGET____GLES_RENDERTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_COLOR____TARGETABLEFLOAT3] = NAME_ELEMENT_COLOR____TARGETABLEFLOAT3;
mHashNameMap[HASH_ELEMENT_COMMENTS] = NAME_ELEMENT_COMMENTS;
mHashNameMap[HASH_ELEMENT_COMMON_COLOR_OR_TEXTURE_TYPE____COLOR] = NAME_ELEMENT_COMMON_COLOR_OR_TEXTURE_TYPE____COLOR;
mHashNameMap[HASH_ELEMENT_COMMON_COLOR_OR_TEXTURE_TYPE____PARAM] = NAME_ELEMENT_COMMON_COLOR_OR_TEXTURE_TYPE____PARAM;
mHashNameMap[HASH_ELEMENT_COMMON_FLOAT_OR_PARAM_TYPE____FLOAT] = NAME_ELEMENT_COMMON_FLOAT_OR_PARAM_TYPE____FLOAT;
mHashNameMap[HASH_ELEMENT_COMMON_FLOAT_OR_PARAM_TYPE____PARAM] = NAME_ELEMENT_COMMON_FLOAT_OR_PARAM_TYPE____PARAM;
mHashNameMap[HASH_ELEMENT_COMPILER_OPTIONS] = NAME_ELEMENT_COMPILER_OPTIONS;
mHashNameMap[HASH_ELEMENT_COMPILER_TARGET] = NAME_ELEMENT_COMPILER_TARGET;
mHashNameMap[HASH_ELEMENT_CONNECT_PARAM] = NAME_ELEMENT_CONNECT_PARAM;
mHashNameMap[HASH_ELEMENT_CONSTANT] = NAME_ELEMENT_CONSTANT;
mHashNameMap[HASH_ELEMENT_CONSTANT_ATTENUATION] = NAME_ELEMENT_CONSTANT_ATTENUATION;
mHashNameMap[HASH_ELEMENT_CONSTANT____GLES_TEXTURE_CONSTANT_TYPE] = NAME_ELEMENT_CONSTANT____GLES_TEXTURE_CONSTANT_TYPE;
mHashNameMap[HASH_ELEMENT_CONTRIBUTOR] = NAME_ELEMENT_CONTRIBUTOR;
mHashNameMap[HASH_ELEMENT_CONTROLLER] = NAME_ELEMENT_CONTROLLER;
mHashNameMap[HASH_ELEMENT_CONTROL_VERTICES] = NAME_ELEMENT_CONTROL_VERTICES;
mHashNameMap[HASH_ELEMENT_CONVEX_MESH] = NAME_ELEMENT_CONVEX_MESH;
mHashNameMap[HASH_ELEMENT_COPYRIGHT] = NAME_ELEMENT_COPYRIGHT;
mHashNameMap[HASH_ELEMENT_CREATED] = NAME_ELEMENT_CREATED;
mHashNameMap[HASH_ELEMENT_CULL_FACE] = NAME_ELEMENT_CULL_FACE;
mHashNameMap[HASH_ELEMENT_CULL_FACE_ENABLE] = NAME_ELEMENT_CULL_FACE_ENABLE;
mHashNameMap[HASH_ELEMENT_CYLINDER] = NAME_ELEMENT_CYLINDER;
mHashNameMap[HASH_ELEMENT_DAMPING] = NAME_ELEMENT_DAMPING;
mHashNameMap[HASH_ELEMENT_DATA] = NAME_ELEMENT_DATA;
mHashNameMap[HASH_ELEMENT_DENSITY] = NAME_ELEMENT_DENSITY;
mHashNameMap[HASH_ELEMENT_DEPTH_BOUNDS] = NAME_ELEMENT_DEPTH_BOUNDS;
mHashNameMap[HASH_ELEMENT_DEPTH_BOUNDS_ENABLE] = NAME_ELEMENT_DEPTH_BOUNDS_ENABLE;
mHashNameMap[HASH_ELEMENT_DEPTH_CLAMP_ENABLE] = NAME_ELEMENT_DEPTH_CLAMP_ENABLE;
mHashNameMap[HASH_ELEMENT_DEPTH_CLEAR] = NAME_ELEMENT_DEPTH_CLEAR;
mHashNameMap[HASH_ELEMENT_DEPTH_CLEAR____FLOAT] = NAME_ELEMENT_DEPTH_CLEAR____FLOAT;
mHashNameMap[HASH_ELEMENT_DEPTH_CLEAR____FX_CLEARDEPTH_COMMON] = NAME_ELEMENT_DEPTH_CLEAR____FX_CLEARDEPTH_COMMON;
mHashNameMap[HASH_ELEMENT_DEPTH_FUNC] = NAME_ELEMENT_DEPTH_FUNC;
mHashNameMap[HASH_ELEMENT_DEPTH_MASK] = NAME_ELEMENT_DEPTH_MASK;
mHashNameMap[HASH_ELEMENT_DEPTH_RANGE] = NAME_ELEMENT_DEPTH_RANGE;
mHashNameMap[HASH_ELEMENT_DEPTH_TARGET] = NAME_ELEMENT_DEPTH_TARGET;
mHashNameMap[HASH_ELEMENT_DEPTH_TARGET____FX_DEPTHTARGET_COMMON] = NAME_ELEMENT_DEPTH_TARGET____FX_DEPTHTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_DEPTH_TARGET____GLES_RENDERTARGET_COMMON] = NAME_ELEMENT_DEPTH_TARGET____GLES_RENDERTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_DEPTH_TEST_ENABLE] = NAME_ELEMENT_DEPTH_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_DEST] = NAME_ELEMENT_DEST;
mHashNameMap[HASH_ELEMENT_DEST_ALPHA] = NAME_ELEMENT_DEST_ALPHA;
mHashNameMap[HASH_ELEMENT_DEST_RGB] = NAME_ELEMENT_DEST_RGB;
mHashNameMap[HASH_ELEMENT_DIFFUSE] = NAME_ELEMENT_DIFFUSE;
mHashNameMap[HASH_ELEMENT_DIRECTIONAL] = NAME_ELEMENT_DIRECTIONAL;
mHashNameMap[HASH_ELEMENT_DITHER_ENABLE] = NAME_ELEMENT_DITHER_ENABLE;
mHashNameMap[HASH_ELEMENT_DRAW] = NAME_ELEMENT_DRAW;
mHashNameMap[HASH_ELEMENT_DYNAMIC] = NAME_ELEMENT_DYNAMIC;
mHashNameMap[HASH_ELEMENT_DYNAMIC_FRICTION] = NAME_ELEMENT_DYNAMIC_FRICTION;
mHashNameMap[HASH_ELEMENT_EFFECT] = NAME_ELEMENT_EFFECT;
mHashNameMap[HASH_ELEMENT_ELLIPSOID] = NAME_ELEMENT_ELLIPSOID;
mHashNameMap[HASH_ELEMENT_EMISSION] = NAME_ELEMENT_EMISSION;
mHashNameMap[HASH_ELEMENT_ENABLED] = NAME_ELEMENT_ENABLED;
mHashNameMap[HASH_ELEMENT_ENUM] = NAME_ELEMENT_ENUM;
mHashNameMap[HASH_ELEMENT_ENUM____GLES_ENUMERATION] = NAME_ELEMENT_ENUM____GLES_ENUMERATION;
mHashNameMap[HASH_ELEMENT_ENUM____GL_ENUMERATION] = NAME_ELEMENT_ENUM____GL_ENUMERATION;
mHashNameMap[HASH_ELEMENT_ENUM____STRING] = NAME_ELEMENT_ENUM____STRING;
mHashNameMap[HASH_ELEMENT_EQUATION] = NAME_ELEMENT_EQUATION;
mHashNameMap[HASH_ELEMENT_EVALUATE_SCENE] = NAME_ELEMENT_EVALUATE_SCENE;
mHashNameMap[HASH_ELEMENT_EXTRA] = NAME_ELEMENT_EXTRA;
mHashNameMap[HASH_ELEMENT_FACE] = NAME_ELEMENT_FACE;
mHashNameMap[HASH_ELEMENT_FAIL] = NAME_ELEMENT_FAIL;
mHashNameMap[HASH_ELEMENT_FALLOFF_ANGLE] = NAME_ELEMENT_FALLOFF_ANGLE;
mHashNameMap[HASH_ELEMENT_FALLOFF_EXPONENT] = NAME_ELEMENT_FALLOFF_EXPONENT;
mHashNameMap[HASH_ELEMENT_FIXED] = NAME_ELEMENT_FIXED;
mHashNameMap[HASH_ELEMENT_FIXED1] = NAME_ELEMENT_FIXED1;
mHashNameMap[HASH_ELEMENT_FIXED1X1] = NAME_ELEMENT_FIXED1X1;
mHashNameMap[HASH_ELEMENT_FIXED1X2] = NAME_ELEMENT_FIXED1X2;
mHashNameMap[HASH_ELEMENT_FIXED1X3] = NAME_ELEMENT_FIXED1X3;
mHashNameMap[HASH_ELEMENT_FIXED1X4] = NAME_ELEMENT_FIXED1X4;
mHashNameMap[HASH_ELEMENT_FIXED2] = NAME_ELEMENT_FIXED2;
mHashNameMap[HASH_ELEMENT_FIXED2X1] = NAME_ELEMENT_FIXED2X1;
mHashNameMap[HASH_ELEMENT_FIXED2X2] = NAME_ELEMENT_FIXED2X2;
mHashNameMap[HASH_ELEMENT_FIXED2X3] = NAME_ELEMENT_FIXED2X3;
mHashNameMap[HASH_ELEMENT_FIXED2X4] = NAME_ELEMENT_FIXED2X4;
mHashNameMap[HASH_ELEMENT_FIXED3] = NAME_ELEMENT_FIXED3;
mHashNameMap[HASH_ELEMENT_FIXED3X1] = NAME_ELEMENT_FIXED3X1;
mHashNameMap[HASH_ELEMENT_FIXED3X2] = NAME_ELEMENT_FIXED3X2;
mHashNameMap[HASH_ELEMENT_FIXED3X3] = NAME_ELEMENT_FIXED3X3;
mHashNameMap[HASH_ELEMENT_FIXED3X4] = NAME_ELEMENT_FIXED3X4;
mHashNameMap[HASH_ELEMENT_FIXED4] = NAME_ELEMENT_FIXED4;
mHashNameMap[HASH_ELEMENT_FIXED4X1] = NAME_ELEMENT_FIXED4X1;
mHashNameMap[HASH_ELEMENT_FIXED4X2] = NAME_ELEMENT_FIXED4X2;
mHashNameMap[HASH_ELEMENT_FIXED4X3] = NAME_ELEMENT_FIXED4X3;
mHashNameMap[HASH_ELEMENT_FIXED4X4] = NAME_ELEMENT_FIXED4X4;
mHashNameMap[HASH_ELEMENT_FLOAT] = NAME_ELEMENT_FLOAT;
mHashNameMap[HASH_ELEMENT_FLOAT1] = NAME_ELEMENT_FLOAT1;
mHashNameMap[HASH_ELEMENT_FLOAT1X1] = NAME_ELEMENT_FLOAT1X1;
mHashNameMap[HASH_ELEMENT_FLOAT1X1____CG_FLOAT1X1] = NAME_ELEMENT_FLOAT1X1____CG_FLOAT1X1;
mHashNameMap[HASH_ELEMENT_FLOAT1X1____FLOAT] = NAME_ELEMENT_FLOAT1X1____FLOAT;
mHashNameMap[HASH_ELEMENT_FLOAT1X2] = NAME_ELEMENT_FLOAT1X2;
mHashNameMap[HASH_ELEMENT_FLOAT1X2____CG_FLOAT1X2] = NAME_ELEMENT_FLOAT1X2____CG_FLOAT1X2;
mHashNameMap[HASH_ELEMENT_FLOAT1X2____FLOAT2] = NAME_ELEMENT_FLOAT1X2____FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT1X3] = NAME_ELEMENT_FLOAT1X3;
mHashNameMap[HASH_ELEMENT_FLOAT1X3____CG_FLOAT1X3] = NAME_ELEMENT_FLOAT1X3____CG_FLOAT1X3;
mHashNameMap[HASH_ELEMENT_FLOAT1X3____FLOAT3] = NAME_ELEMENT_FLOAT1X3____FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT1X4] = NAME_ELEMENT_FLOAT1X4;
mHashNameMap[HASH_ELEMENT_FLOAT1X4____CG_FLOAT1X4] = NAME_ELEMENT_FLOAT1X4____CG_FLOAT1X4;
mHashNameMap[HASH_ELEMENT_FLOAT1X4____FLOAT4] = NAME_ELEMENT_FLOAT1X4____FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT2] = NAME_ELEMENT_FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT2X1] = NAME_ELEMENT_FLOAT2X1;
mHashNameMap[HASH_ELEMENT_FLOAT2X1____CG_FLOAT2X1] = NAME_ELEMENT_FLOAT2X1____CG_FLOAT2X1;
mHashNameMap[HASH_ELEMENT_FLOAT2X1____FLOAT2] = NAME_ELEMENT_FLOAT2X1____FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT2X2] = NAME_ELEMENT_FLOAT2X2;
mHashNameMap[HASH_ELEMENT_FLOAT2X2____CG_FLOAT2X2] = NAME_ELEMENT_FLOAT2X2____CG_FLOAT2X2;
mHashNameMap[HASH_ELEMENT_FLOAT2X2____FLOAT2X2] = NAME_ELEMENT_FLOAT2X2____FLOAT2X2;
mHashNameMap[HASH_ELEMENT_FLOAT2X2____GLSL_FLOAT2X2] = NAME_ELEMENT_FLOAT2X2____GLSL_FLOAT2X2;
mHashNameMap[HASH_ELEMENT_FLOAT2X3] = NAME_ELEMENT_FLOAT2X3;
mHashNameMap[HASH_ELEMENT_FLOAT2X3____CG_FLOAT2X3] = NAME_ELEMENT_FLOAT2X3____CG_FLOAT2X3;
mHashNameMap[HASH_ELEMENT_FLOAT2X3____FLOAT2X3] = NAME_ELEMENT_FLOAT2X3____FLOAT2X3;
mHashNameMap[HASH_ELEMENT_FLOAT2X4] = NAME_ELEMENT_FLOAT2X4;
mHashNameMap[HASH_ELEMENT_FLOAT2X4____CG_FLOAT2X4] = NAME_ELEMENT_FLOAT2X4____CG_FLOAT2X4;
mHashNameMap[HASH_ELEMENT_FLOAT2X4____FLOAT2X4] = NAME_ELEMENT_FLOAT2X4____FLOAT2X4;
mHashNameMap[HASH_ELEMENT_FLOAT2____CG_FLOAT2] = NAME_ELEMENT_FLOAT2____CG_FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT2____FLOAT2] = NAME_ELEMENT_FLOAT2____FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT2____GLSL_FLOAT2] = NAME_ELEMENT_FLOAT2____GLSL_FLOAT2;
mHashNameMap[HASH_ELEMENT_FLOAT3] = NAME_ELEMENT_FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT3X1] = NAME_ELEMENT_FLOAT3X1;
mHashNameMap[HASH_ELEMENT_FLOAT3X1____CG_FLOAT3X1] = NAME_ELEMENT_FLOAT3X1____CG_FLOAT3X1;
mHashNameMap[HASH_ELEMENT_FLOAT3X1____FLOAT3] = NAME_ELEMENT_FLOAT3X1____FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT3X2] = NAME_ELEMENT_FLOAT3X2;
mHashNameMap[HASH_ELEMENT_FLOAT3X2____CG_FLOAT3X2] = NAME_ELEMENT_FLOAT3X2____CG_FLOAT3X2;
mHashNameMap[HASH_ELEMENT_FLOAT3X2____FLOAT3X2] = NAME_ELEMENT_FLOAT3X2____FLOAT3X2;
mHashNameMap[HASH_ELEMENT_FLOAT3X3] = NAME_ELEMENT_FLOAT3X3;
mHashNameMap[HASH_ELEMENT_FLOAT3X3____CG_FLOAT3X3] = NAME_ELEMENT_FLOAT3X3____CG_FLOAT3X3;
mHashNameMap[HASH_ELEMENT_FLOAT3X3____FLOAT3X3] = NAME_ELEMENT_FLOAT3X3____FLOAT3X3;
mHashNameMap[HASH_ELEMENT_FLOAT3X3____GLSL_FLOAT3X3] = NAME_ELEMENT_FLOAT3X3____GLSL_FLOAT3X3;
mHashNameMap[HASH_ELEMENT_FLOAT3X4] = NAME_ELEMENT_FLOAT3X4;
mHashNameMap[HASH_ELEMENT_FLOAT3X4____CG_FLOAT3X4] = NAME_ELEMENT_FLOAT3X4____CG_FLOAT3X4;
mHashNameMap[HASH_ELEMENT_FLOAT3X4____FLOAT3X4] = NAME_ELEMENT_FLOAT3X4____FLOAT3X4;
mHashNameMap[HASH_ELEMENT_FLOAT3____CG_FLOAT3] = NAME_ELEMENT_FLOAT3____CG_FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT3____FLOAT3] = NAME_ELEMENT_FLOAT3____FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT3____GLSL_FLOAT3] = NAME_ELEMENT_FLOAT3____GLSL_FLOAT3;
mHashNameMap[HASH_ELEMENT_FLOAT4] = NAME_ELEMENT_FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT4X1] = NAME_ELEMENT_FLOAT4X1;
mHashNameMap[HASH_ELEMENT_FLOAT4X1____CG_FLOAT4X1] = NAME_ELEMENT_FLOAT4X1____CG_FLOAT4X1;
mHashNameMap[HASH_ELEMENT_FLOAT4X1____FLOAT4] = NAME_ELEMENT_FLOAT4X1____FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT4X2] = NAME_ELEMENT_FLOAT4X2;
mHashNameMap[HASH_ELEMENT_FLOAT4X2____CG_FLOAT4X2] = NAME_ELEMENT_FLOAT4X2____CG_FLOAT4X2;
mHashNameMap[HASH_ELEMENT_FLOAT4X2____FLOAT4X2] = NAME_ELEMENT_FLOAT4X2____FLOAT4X2;
mHashNameMap[HASH_ELEMENT_FLOAT4X3] = NAME_ELEMENT_FLOAT4X3;
mHashNameMap[HASH_ELEMENT_FLOAT4X3____CG_FLOAT4X3] = NAME_ELEMENT_FLOAT4X3____CG_FLOAT4X3;
mHashNameMap[HASH_ELEMENT_FLOAT4X3____FLOAT4X3] = NAME_ELEMENT_FLOAT4X3____FLOAT4X3;
mHashNameMap[HASH_ELEMENT_FLOAT4X4] = NAME_ELEMENT_FLOAT4X4;
mHashNameMap[HASH_ELEMENT_FLOAT4X4____CG_FLOAT4X4] = NAME_ELEMENT_FLOAT4X4____CG_FLOAT4X4;
mHashNameMap[HASH_ELEMENT_FLOAT4X4____FLOAT4X4] = NAME_ELEMENT_FLOAT4X4____FLOAT4X4;
mHashNameMap[HASH_ELEMENT_FLOAT4X4____GLSL_FLOAT4X4] = NAME_ELEMENT_FLOAT4X4____GLSL_FLOAT4X4;
mHashNameMap[HASH_ELEMENT_FLOAT4____CG_FLOAT4] = NAME_ELEMENT_FLOAT4____CG_FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT4____FLOAT4] = NAME_ELEMENT_FLOAT4____FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT4____GLSL_FLOAT4] = NAME_ELEMENT_FLOAT4____GLSL_FLOAT4;
mHashNameMap[HASH_ELEMENT_FLOAT_ARRAY] = NAME_ELEMENT_FLOAT_ARRAY;
mHashNameMap[HASH_ELEMENT_FLOAT____CG_FLOAT] = NAME_ELEMENT_FLOAT____CG_FLOAT;
mHashNameMap[HASH_ELEMENT_FLOAT____FLOAT] = NAME_ELEMENT_FLOAT____FLOAT;
mHashNameMap[HASH_ELEMENT_FLOAT____GLSL_FLOAT] = NAME_ELEMENT_FLOAT____GLSL_FLOAT;
mHashNameMap[HASH_ELEMENT_FOG_COLOR] = NAME_ELEMENT_FOG_COLOR;
mHashNameMap[HASH_ELEMENT_FOG_COORD_SRC] = NAME_ELEMENT_FOG_COORD_SRC;
mHashNameMap[HASH_ELEMENT_FOG_DENSITY] = NAME_ELEMENT_FOG_DENSITY;
mHashNameMap[HASH_ELEMENT_FOG_ENABLE] = NAME_ELEMENT_FOG_ENABLE;
mHashNameMap[HASH_ELEMENT_FOG_END] = NAME_ELEMENT_FOG_END;
mHashNameMap[HASH_ELEMENT_FOG_MODE] = NAME_ELEMENT_FOG_MODE;
mHashNameMap[HASH_ELEMENT_FOG_START] = NAME_ELEMENT_FOG_START;
mHashNameMap[HASH_ELEMENT_FORCE_FIELD] = NAME_ELEMENT_FORCE_FIELD;
mHashNameMap[HASH_ELEMENT_FORMAT] = NAME_ELEMENT_FORMAT;
mHashNameMap[HASH_ELEMENT_FORMAT_HINT] = NAME_ELEMENT_FORMAT_HINT;
mHashNameMap[HASH_ELEMENT_FRONT] = NAME_ELEMENT_FRONT;
mHashNameMap[HASH_ELEMENT_FRONT_FACE] = NAME_ELEMENT_FRONT_FACE;
mHashNameMap[HASH_ELEMENT_FUNC] = NAME_ELEMENT_FUNC;
mHashNameMap[HASH_ELEMENT_FX_PROFILE_ABSTRACT] = NAME_ELEMENT_FX_PROFILE_ABSTRACT;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____ALL] = NAME_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____ALL;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____FACE] = NAME_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____FACE;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____PRIMARY] = NAME_ELEMENT_FX_SURFACE_INIT_CUBE_COMMON____PRIMARY;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_PLANAR_COMMON____ALL] = NAME_ELEMENT_FX_SURFACE_INIT_PLANAR_COMMON____ALL;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_VOLUME_COMMON____ALL] = NAME_ELEMENT_FX_SURFACE_INIT_VOLUME_COMMON____ALL;
mHashNameMap[HASH_ELEMENT_FX_SURFACE_INIT_VOLUME_COMMON____PRIMARY] = NAME_ELEMENT_FX_SURFACE_INIT_VOLUME_COMMON____PRIMARY;
mHashNameMap[HASH_ELEMENT_GENERATOR] = NAME_ELEMENT_GENERATOR;
mHashNameMap[HASH_ELEMENT_GEOMETRY] = NAME_ELEMENT_GEOMETRY;
mHashNameMap[HASH_ELEMENT_GLSL_SURFACE_TYPE____GENERATOR] = NAME_ELEMENT_GLSL_SURFACE_TYPE____GENERATOR;
mHashNameMap[HASH_ELEMENT_GL_HOOK_ABSTRACT] = NAME_ELEMENT_GL_HOOK_ABSTRACT;
mHashNameMap[HASH_ELEMENT_GRAVITY] = NAME_ELEMENT_GRAVITY;
mHashNameMap[HASH_ELEMENT_H] = NAME_ELEMENT_H;
mHashNameMap[HASH_ELEMENT_HALF] = NAME_ELEMENT_HALF;
mHashNameMap[HASH_ELEMENT_HALF1] = NAME_ELEMENT_HALF1;
mHashNameMap[HASH_ELEMENT_HALF1X1] = NAME_ELEMENT_HALF1X1;
mHashNameMap[HASH_ELEMENT_HALF1X2] = NAME_ELEMENT_HALF1X2;
mHashNameMap[HASH_ELEMENT_HALF1X3] = NAME_ELEMENT_HALF1X3;
mHashNameMap[HASH_ELEMENT_HALF1X4] = NAME_ELEMENT_HALF1X4;
mHashNameMap[HASH_ELEMENT_HALF2] = NAME_ELEMENT_HALF2;
mHashNameMap[HASH_ELEMENT_HALF2X1] = NAME_ELEMENT_HALF2X1;
mHashNameMap[HASH_ELEMENT_HALF2X2] = NAME_ELEMENT_HALF2X2;
mHashNameMap[HASH_ELEMENT_HALF2X3] = NAME_ELEMENT_HALF2X3;
mHashNameMap[HASH_ELEMENT_HALF2X4] = NAME_ELEMENT_HALF2X4;
mHashNameMap[HASH_ELEMENT_HALF3] = NAME_ELEMENT_HALF3;
mHashNameMap[HASH_ELEMENT_HALF3X1] = NAME_ELEMENT_HALF3X1;
mHashNameMap[HASH_ELEMENT_HALF3X2] = NAME_ELEMENT_HALF3X2;
mHashNameMap[HASH_ELEMENT_HALF3X3] = NAME_ELEMENT_HALF3X3;
mHashNameMap[HASH_ELEMENT_HALF3X4] = NAME_ELEMENT_HALF3X4;
mHashNameMap[HASH_ELEMENT_HALF4] = NAME_ELEMENT_HALF4;
mHashNameMap[HASH_ELEMENT_HALF4X1] = NAME_ELEMENT_HALF4X1;
mHashNameMap[HASH_ELEMENT_HALF4X2] = NAME_ELEMENT_HALF4X2;
mHashNameMap[HASH_ELEMENT_HALF4X3] = NAME_ELEMENT_HALF4X3;
mHashNameMap[HASH_ELEMENT_HALF4X4] = NAME_ELEMENT_HALF4X4;
mHashNameMap[HASH_ELEMENT_HALF_EXTENTS] = NAME_ELEMENT_HALF_EXTENTS;
mHashNameMap[HASH_ELEMENT_HEIGHT] = NAME_ELEMENT_HEIGHT;
mHashNameMap[HASH_ELEMENT_HOLLOW] = NAME_ELEMENT_HOLLOW;
mHashNameMap[HASH_ELEMENT_IDREF_ARRAY] = NAME_ELEMENT_IDREF_ARRAY;
mHashNameMap[HASH_ELEMENT_IMAGE] = NAME_ELEMENT_IMAGE;
mHashNameMap[HASH_ELEMENT_IMAGER] = NAME_ELEMENT_IMAGER;
mHashNameMap[HASH_ELEMENT_INCLUDE] = NAME_ELEMENT_INCLUDE;
mHashNameMap[HASH_ELEMENT_INDEX_OF_REFRACTION] = NAME_ELEMENT_INDEX_OF_REFRACTION;
mHashNameMap[HASH_ELEMENT_INERTIA] = NAME_ELEMENT_INERTIA;
mHashNameMap[HASH_ELEMENT_INIT_AS_NULL] = NAME_ELEMENT_INIT_AS_NULL;
mHashNameMap[HASH_ELEMENT_INIT_AS_TARGET] = NAME_ELEMENT_INIT_AS_TARGET;
mHashNameMap[HASH_ELEMENT_INIT_CUBE] = NAME_ELEMENT_INIT_CUBE;
mHashNameMap[HASH_ELEMENT_INIT_FROM] = NAME_ELEMENT_INIT_FROM;
mHashNameMap[HASH_ELEMENT_INIT_FROM____ANYURI] = NAME_ELEMENT_INIT_FROM____ANYURI;
mHashNameMap[HASH_ELEMENT_INIT_FROM____FX_SURFACE_INIT_FROM_COMMON] = NAME_ELEMENT_INIT_FROM____FX_SURFACE_INIT_FROM_COMMON;
mHashNameMap[HASH_ELEMENT_INIT_PLANAR] = NAME_ELEMENT_INIT_PLANAR;
mHashNameMap[HASH_ELEMENT_INIT_VOLUME] = NAME_ELEMENT_INIT_VOLUME;
mHashNameMap[HASH_ELEMENT_INPUT] = NAME_ELEMENT_INPUT;
mHashNameMap[HASH_ELEMENT_INPUT____INPUTLOCAL] = NAME_ELEMENT_INPUT____INPUTLOCAL;
mHashNameMap[HASH_ELEMENT_INPUT____INPUTLOCALOFFSET] = NAME_ELEMENT_INPUT____INPUTLOCALOFFSET;
mHashNameMap[HASH_ELEMENT_INSTANCE_ANIMATION] = NAME_ELEMENT_INSTANCE_ANIMATION;
mHashNameMap[HASH_ELEMENT_INSTANCE_CAMERA] = NAME_ELEMENT_INSTANCE_CAMERA;
mHashNameMap[HASH_ELEMENT_INSTANCE_CONTROLLER] = NAME_ELEMENT_INSTANCE_CONTROLLER;
mHashNameMap[HASH_ELEMENT_INSTANCE_EFFECT] = NAME_ELEMENT_INSTANCE_EFFECT;
mHashNameMap[HASH_ELEMENT_INSTANCE_EFFECT__SETPARAM] = NAME_ELEMENT_INSTANCE_EFFECT__SETPARAM;
mHashNameMap[HASH_ELEMENT_INSTANCE_FORCE_FIELD] = NAME_ELEMENT_INSTANCE_FORCE_FIELD;
mHashNameMap[HASH_ELEMENT_INSTANCE_GEOMETRY] = NAME_ELEMENT_INSTANCE_GEOMETRY;
mHashNameMap[HASH_ELEMENT_INSTANCE_LIGHT] = NAME_ELEMENT_INSTANCE_LIGHT;
mHashNameMap[HASH_ELEMENT_INSTANCE_MATERIAL] = NAME_ELEMENT_INSTANCE_MATERIAL;
mHashNameMap[HASH_ELEMENT_INSTANCE_MATERIAL__BIND] = NAME_ELEMENT_INSTANCE_MATERIAL__BIND;
mHashNameMap[HASH_ELEMENT_INSTANCE_NODE] = NAME_ELEMENT_INSTANCE_NODE;
mHashNameMap[HASH_ELEMENT_INSTANCE_PHYSICS_MATERIAL] = NAME_ELEMENT_INSTANCE_PHYSICS_MATERIAL;
mHashNameMap[HASH_ELEMENT_INSTANCE_PHYSICS_MODEL] = NAME_ELEMENT_INSTANCE_PHYSICS_MODEL;
mHashNameMap[HASH_ELEMENT_INSTANCE_PHYSICS_SCENE] = NAME_ELEMENT_INSTANCE_PHYSICS_SCENE;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY] = NAME_ELEMENT_INSTANCE_RIGID_BODY;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON] = NAME_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__DYNAMIC] = NAME_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__DYNAMIC;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__MASS_FRAME] = NAME_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__MASS_FRAME;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__SHAPE] = NAME_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__SHAPE;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__SHAPE__HOLLOW] = NAME_ELEMENT_INSTANCE_RIGID_BODY__TECHNIQUE_COMMON__SHAPE__HOLLOW;
mHashNameMap[HASH_ELEMENT_INSTANCE_RIGID_CONSTRAINT] = NAME_ELEMENT_INSTANCE_RIGID_CONSTRAINT;
mHashNameMap[HASH_ELEMENT_INSTANCE_VISUAL_SCENE] = NAME_ELEMENT_INSTANCE_VISUAL_SCENE;
mHashNameMap[HASH_ELEMENT_INT] = NAME_ELEMENT_INT;
mHashNameMap[HASH_ELEMENT_INT1] = NAME_ELEMENT_INT1;
mHashNameMap[HASH_ELEMENT_INT1X1] = NAME_ELEMENT_INT1X1;
mHashNameMap[HASH_ELEMENT_INT1X2] = NAME_ELEMENT_INT1X2;
mHashNameMap[HASH_ELEMENT_INT1X3] = NAME_ELEMENT_INT1X3;
mHashNameMap[HASH_ELEMENT_INT1X4] = NAME_ELEMENT_INT1X4;
mHashNameMap[HASH_ELEMENT_INT2] = NAME_ELEMENT_INT2;
mHashNameMap[HASH_ELEMENT_INT2X1] = NAME_ELEMENT_INT2X1;
mHashNameMap[HASH_ELEMENT_INT2X2] = NAME_ELEMENT_INT2X2;
mHashNameMap[HASH_ELEMENT_INT2X3] = NAME_ELEMENT_INT2X3;
mHashNameMap[HASH_ELEMENT_INT2X4] = NAME_ELEMENT_INT2X4;
mHashNameMap[HASH_ELEMENT_INT2____CG_INT2] = NAME_ELEMENT_INT2____CG_INT2;
mHashNameMap[HASH_ELEMENT_INT2____GLSL_INT2] = NAME_ELEMENT_INT2____GLSL_INT2;
mHashNameMap[HASH_ELEMENT_INT2____INT2] = NAME_ELEMENT_INT2____INT2;
mHashNameMap[HASH_ELEMENT_INT3] = NAME_ELEMENT_INT3;
mHashNameMap[HASH_ELEMENT_INT3X1] = NAME_ELEMENT_INT3X1;
mHashNameMap[HASH_ELEMENT_INT3X2] = NAME_ELEMENT_INT3X2;
mHashNameMap[HASH_ELEMENT_INT3X3] = NAME_ELEMENT_INT3X3;
mHashNameMap[HASH_ELEMENT_INT3X4] = NAME_ELEMENT_INT3X4;
mHashNameMap[HASH_ELEMENT_INT3____CG_INT3] = NAME_ELEMENT_INT3____CG_INT3;
mHashNameMap[HASH_ELEMENT_INT3____GLSL_INT3] = NAME_ELEMENT_INT3____GLSL_INT3;
mHashNameMap[HASH_ELEMENT_INT3____INT3] = NAME_ELEMENT_INT3____INT3;
mHashNameMap[HASH_ELEMENT_INT4] = NAME_ELEMENT_INT4;
mHashNameMap[HASH_ELEMENT_INT4X1] = NAME_ELEMENT_INT4X1;
mHashNameMap[HASH_ELEMENT_INT4X2] = NAME_ELEMENT_INT4X2;
mHashNameMap[HASH_ELEMENT_INT4X3] = NAME_ELEMENT_INT4X3;
mHashNameMap[HASH_ELEMENT_INT4X4] = NAME_ELEMENT_INT4X4;
mHashNameMap[HASH_ELEMENT_INT4____CG_INT4] = NAME_ELEMENT_INT4____CG_INT4;
mHashNameMap[HASH_ELEMENT_INT4____GLSL_INT4] = NAME_ELEMENT_INT4____GLSL_INT4;
mHashNameMap[HASH_ELEMENT_INT4____INT4] = NAME_ELEMENT_INT4____INT4;
mHashNameMap[HASH_ELEMENT_INTERPENETRATE] = NAME_ELEMENT_INTERPENETRATE;
mHashNameMap[HASH_ELEMENT_INT_ARRAY] = NAME_ELEMENT_INT_ARRAY;
mHashNameMap[HASH_ELEMENT_INT____CG_INT] = NAME_ELEMENT_INT____CG_INT;
mHashNameMap[HASH_ELEMENT_INT____GLSL_INT] = NAME_ELEMENT_INT____GLSL_INT;
mHashNameMap[HASH_ELEMENT_INT____INT] = NAME_ELEMENT_INT____INT;
mHashNameMap[HASH_ELEMENT_JOINTS] = NAME_ELEMENT_JOINTS;
mHashNameMap[HASH_ELEMENT_KEYWORDS] = NAME_ELEMENT_KEYWORDS;
mHashNameMap[HASH_ELEMENT_LAMBERT] = NAME_ELEMENT_LAMBERT;
mHashNameMap[HASH_ELEMENT_LAYER] = NAME_ELEMENT_LAYER;
mHashNameMap[HASH_ELEMENT_LIBRARY_ANIMATIONS] = NAME_ELEMENT_LIBRARY_ANIMATIONS;
mHashNameMap[HASH_ELEMENT_LIBRARY_ANIMATION_CLIPS] = NAME_ELEMENT_LIBRARY_ANIMATION_CLIPS;
mHashNameMap[HASH_ELEMENT_LIBRARY_CAMERAS] = NAME_ELEMENT_LIBRARY_CAMERAS;
mHashNameMap[HASH_ELEMENT_LIBRARY_CONTROLLERS] = NAME_ELEMENT_LIBRARY_CONTROLLERS;
mHashNameMap[HASH_ELEMENT_LIBRARY_EFFECTS] = NAME_ELEMENT_LIBRARY_EFFECTS;
mHashNameMap[HASH_ELEMENT_LIBRARY_FORCE_FIELDS] = NAME_ELEMENT_LIBRARY_FORCE_FIELDS;
mHashNameMap[HASH_ELEMENT_LIBRARY_GEOMETRIES] = NAME_ELEMENT_LIBRARY_GEOMETRIES;
mHashNameMap[HASH_ELEMENT_LIBRARY_IMAGES] = NAME_ELEMENT_LIBRARY_IMAGES;
mHashNameMap[HASH_ELEMENT_LIBRARY_LIGHTS] = NAME_ELEMENT_LIBRARY_LIGHTS;
mHashNameMap[HASH_ELEMENT_LIBRARY_MATERIALS] = NAME_ELEMENT_LIBRARY_MATERIALS;
mHashNameMap[HASH_ELEMENT_LIBRARY_NODES] = NAME_ELEMENT_LIBRARY_NODES;
mHashNameMap[HASH_ELEMENT_LIBRARY_PHYSICS_MATERIALS] = NAME_ELEMENT_LIBRARY_PHYSICS_MATERIALS;
mHashNameMap[HASH_ELEMENT_LIBRARY_PHYSICS_MODELS] = NAME_ELEMENT_LIBRARY_PHYSICS_MODELS;
mHashNameMap[HASH_ELEMENT_LIBRARY_PHYSICS_SCENES] = NAME_ELEMENT_LIBRARY_PHYSICS_SCENES;
mHashNameMap[HASH_ELEMENT_LIBRARY_VISUAL_SCENES] = NAME_ELEMENT_LIBRARY_VISUAL_SCENES;
mHashNameMap[HASH_ELEMENT_LIGHT] = NAME_ELEMENT_LIGHT;
mHashNameMap[HASH_ELEMENT_LIGHTING_ENABLE] = NAME_ELEMENT_LIGHTING_ENABLE;
mHashNameMap[HASH_ELEMENT_LIGHT_AMBIENT] = NAME_ELEMENT_LIGHT_AMBIENT;
mHashNameMap[HASH_ELEMENT_LIGHT_CONSTANT_ATTENUATION] = NAME_ELEMENT_LIGHT_CONSTANT_ATTENUATION;
mHashNameMap[HASH_ELEMENT_LIGHT_DIFFUSE] = NAME_ELEMENT_LIGHT_DIFFUSE;
mHashNameMap[HASH_ELEMENT_LIGHT_ENABLE] = NAME_ELEMENT_LIGHT_ENABLE;
mHashNameMap[HASH_ELEMENT_LIGHT_LINEAR_ATTENUATION] = NAME_ELEMENT_LIGHT_LINEAR_ATTENUATION;
mHashNameMap[HASH_ELEMENT_LIGHT_LINEAR_ATTENUTATION] = NAME_ELEMENT_LIGHT_LINEAR_ATTENUTATION;
mHashNameMap[HASH_ELEMENT_LIGHT_MODEL_AMBIENT] = NAME_ELEMENT_LIGHT_MODEL_AMBIENT;
mHashNameMap[HASH_ELEMENT_LIGHT_MODEL_COLOR_CONTROL] = NAME_ELEMENT_LIGHT_MODEL_COLOR_CONTROL;
mHashNameMap[HASH_ELEMENT_LIGHT_MODEL_LOCAL_VIEWER_ENABLE] = NAME_ELEMENT_LIGHT_MODEL_LOCAL_VIEWER_ENABLE;
mHashNameMap[HASH_ELEMENT_LIGHT_MODEL_TWO_SIDE_ENABLE] = NAME_ELEMENT_LIGHT_MODEL_TWO_SIDE_ENABLE;
mHashNameMap[HASH_ELEMENT_LIGHT_POSITION] = NAME_ELEMENT_LIGHT_POSITION;
mHashNameMap[HASH_ELEMENT_LIGHT_QUADRATIC_ATTENUATION] = NAME_ELEMENT_LIGHT_QUADRATIC_ATTENUATION;
mHashNameMap[HASH_ELEMENT_LIGHT_SPECULAR] = NAME_ELEMENT_LIGHT_SPECULAR;
mHashNameMap[HASH_ELEMENT_LIGHT_SPOT_CUTOFF] = NAME_ELEMENT_LIGHT_SPOT_CUTOFF;
mHashNameMap[HASH_ELEMENT_LIGHT_SPOT_DIRECTION] = NAME_ELEMENT_LIGHT_SPOT_DIRECTION;
mHashNameMap[HASH_ELEMENT_LIGHT_SPOT_EXPONENT] = NAME_ELEMENT_LIGHT_SPOT_EXPONENT;
mHashNameMap[HASH_ELEMENT_LIGHT__TECHNIQUE_COMMON] = NAME_ELEMENT_LIGHT__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_LIGHT__TECHNIQUE_COMMON__AMBIENT] = NAME_ELEMENT_LIGHT__TECHNIQUE_COMMON__AMBIENT;
mHashNameMap[HASH_ELEMENT_LIMITS] = NAME_ELEMENT_LIMITS;
mHashNameMap[HASH_ELEMENT_LIMITS__LINEAR] = NAME_ELEMENT_LIMITS__LINEAR;
mHashNameMap[HASH_ELEMENT_LINEAR] = NAME_ELEMENT_LINEAR;
mHashNameMap[HASH_ELEMENT_LINEAR_ATTENUATION] = NAME_ELEMENT_LINEAR_ATTENUATION;
mHashNameMap[HASH_ELEMENT_LINES] = NAME_ELEMENT_LINES;
mHashNameMap[HASH_ELEMENT_LINESTRIPS] = NAME_ELEMENT_LINESTRIPS;
mHashNameMap[HASH_ELEMENT_LINE_SMOOTH_ENABLE] = NAME_ELEMENT_LINE_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_LINE_STIPPLE] = NAME_ELEMENT_LINE_STIPPLE;
mHashNameMap[HASH_ELEMENT_LINE_STIPPLE_ENABLE] = NAME_ELEMENT_LINE_STIPPLE_ENABLE;
mHashNameMap[HASH_ELEMENT_LINE_WIDTH] = NAME_ELEMENT_LINE_WIDTH;
mHashNameMap[HASH_ELEMENT_LOGIC_OP] = NAME_ELEMENT_LOGIC_OP;
mHashNameMap[HASH_ELEMENT_LOGIC_OP_ENABLE] = NAME_ELEMENT_LOGIC_OP_ENABLE;
mHashNameMap[HASH_ELEMENT_LOOKAT] = NAME_ELEMENT_LOOKAT;
mHashNameMap[HASH_ELEMENT_MAGFILTER] = NAME_ELEMENT_MAGFILTER;
mHashNameMap[HASH_ELEMENT_MASK] = NAME_ELEMENT_MASK;
mHashNameMap[HASH_ELEMENT_MASS] = NAME_ELEMENT_MASS;
mHashNameMap[HASH_ELEMENT_MASS_FRAME] = NAME_ELEMENT_MASS_FRAME;
mHashNameMap[HASH_ELEMENT_MATERIAL] = NAME_ELEMENT_MATERIAL;
mHashNameMap[HASH_ELEMENT_MATERIAL_AMBIENT] = NAME_ELEMENT_MATERIAL_AMBIENT;
mHashNameMap[HASH_ELEMENT_MATERIAL_DIFFUSE] = NAME_ELEMENT_MATERIAL_DIFFUSE;
mHashNameMap[HASH_ELEMENT_MATERIAL_EMISSION] = NAME_ELEMENT_MATERIAL_EMISSION;
mHashNameMap[HASH_ELEMENT_MATERIAL_SHININESS] = NAME_ELEMENT_MATERIAL_SHININESS;
mHashNameMap[HASH_ELEMENT_MATERIAL_SPECULAR] = NAME_ELEMENT_MATERIAL_SPECULAR;
mHashNameMap[HASH_ELEMENT_MATRIX] = NAME_ELEMENT_MATRIX;
mHashNameMap[HASH_ELEMENT_MAX] = NAME_ELEMENT_MAX;
mHashNameMap[HASH_ELEMENT_MESH] = NAME_ELEMENT_MESH;
mHashNameMap[HASH_ELEMENT_MIN] = NAME_ELEMENT_MIN;
mHashNameMap[HASH_ELEMENT_MINFILTER] = NAME_ELEMENT_MINFILTER;
mHashNameMap[HASH_ELEMENT_MIPFILTER] = NAME_ELEMENT_MIPFILTER;
mHashNameMap[HASH_ELEMENT_MIPMAP_BIAS] = NAME_ELEMENT_MIPMAP_BIAS;
mHashNameMap[HASH_ELEMENT_MIPMAP_GENERATE] = NAME_ELEMENT_MIPMAP_GENERATE;
mHashNameMap[HASH_ELEMENT_MIPMAP_MAXLEVEL] = NAME_ELEMENT_MIPMAP_MAXLEVEL;
mHashNameMap[HASH_ELEMENT_MIP_LEVELS] = NAME_ELEMENT_MIP_LEVELS;
mHashNameMap[HASH_ELEMENT_MODE] = NAME_ELEMENT_MODE;
mHashNameMap[HASH_ELEMENT_MODEL_VIEW_MATRIX] = NAME_ELEMENT_MODEL_VIEW_MATRIX;
mHashNameMap[HASH_ELEMENT_MODIFIED] = NAME_ELEMENT_MODIFIED;
mHashNameMap[HASH_ELEMENT_MODIFIER] = NAME_ELEMENT_MODIFIER;
mHashNameMap[HASH_ELEMENT_MORPH] = NAME_ELEMENT_MORPH;
mHashNameMap[HASH_ELEMENT_MULTISAMPLE_ENABLE] = NAME_ELEMENT_MULTISAMPLE_ENABLE;
mHashNameMap[HASH_ELEMENT_NAME] = NAME_ELEMENT_NAME;
mHashNameMap[HASH_ELEMENT_NAME_ARRAY] = NAME_ELEMENT_NAME_ARRAY;
mHashNameMap[HASH_ELEMENT_NEWPARAM] = NAME_ELEMENT_NEWPARAM;
mHashNameMap[HASH_ELEMENT_NEWPARAM____CG_NEWPARAM] = NAME_ELEMENT_NEWPARAM____CG_NEWPARAM;
mHashNameMap[HASH_ELEMENT_NEWPARAM____COMMON_NEWPARAM_TYPE] = NAME_ELEMENT_NEWPARAM____COMMON_NEWPARAM_TYPE;
mHashNameMap[HASH_ELEMENT_NEWPARAM____FX_NEWPARAM_COMMON] = NAME_ELEMENT_NEWPARAM____FX_NEWPARAM_COMMON;
mHashNameMap[HASH_ELEMENT_NEWPARAM____GLES_NEWPARAM] = NAME_ELEMENT_NEWPARAM____GLES_NEWPARAM;
mHashNameMap[HASH_ELEMENT_NEWPARAM____GLSL_NEWPARAM] = NAME_ELEMENT_NEWPARAM____GLSL_NEWPARAM;
mHashNameMap[HASH_ELEMENT_NODE] = NAME_ELEMENT_NODE;
mHashNameMap[HASH_ELEMENT_NORMALIZE_ENABLE] = NAME_ELEMENT_NORMALIZE_ENABLE;
mHashNameMap[HASH_ELEMENT_OPTICS] = NAME_ELEMENT_OPTICS;
mHashNameMap[HASH_ELEMENT_OPTICS__TECHNIQUE_COMMON] = NAME_ELEMENT_OPTICS__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_OPTION] = NAME_ELEMENT_OPTION;
mHashNameMap[HASH_ELEMENT_ORDER] = NAME_ELEMENT_ORDER;
mHashNameMap[HASH_ELEMENT_ORTHOGRAPHIC] = NAME_ELEMENT_ORTHOGRAPHIC;
mHashNameMap[HASH_ELEMENT_P] = NAME_ELEMENT_P;
mHashNameMap[HASH_ELEMENT_PARAM] = NAME_ELEMENT_PARAM;
mHashNameMap[HASH_ELEMENT_PARAM____NCNAME] = NAME_ELEMENT_PARAM____NCNAME;
mHashNameMap[HASH_ELEMENT_PASS] = NAME_ELEMENT_PASS;
mHashNameMap[HASH_ELEMENT_PERSPECTIVE] = NAME_ELEMENT_PERSPECTIVE;
mHashNameMap[HASH_ELEMENT_PH] = NAME_ELEMENT_PH;
mHashNameMap[HASH_ELEMENT_PHONG] = NAME_ELEMENT_PHONG;
mHashNameMap[HASH_ELEMENT_PHYSICS_MATERIAL] = NAME_ELEMENT_PHYSICS_MATERIAL;
mHashNameMap[HASH_ELEMENT_PHYSICS_MATERIAL__TECHNIQUE_COMMON] = NAME_ELEMENT_PHYSICS_MATERIAL__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_PHYSICS_MODEL] = NAME_ELEMENT_PHYSICS_MODEL;
mHashNameMap[HASH_ELEMENT_PHYSICS_SCENE] = NAME_ELEMENT_PHYSICS_SCENE;
mHashNameMap[HASH_ELEMENT_PHYSICS_SCENE__TECHNIQUE_COMMON] = NAME_ELEMENT_PHYSICS_SCENE__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_PLANE] = NAME_ELEMENT_PLANE;
mHashNameMap[HASH_ELEMENT_POINT] = NAME_ELEMENT_POINT;
mHashNameMap[HASH_ELEMENT_POINT_DISTANCE_ATTENUATION] = NAME_ELEMENT_POINT_DISTANCE_ATTENUATION;
mHashNameMap[HASH_ELEMENT_POINT_FADE_THRESHOLD_SIZE] = NAME_ELEMENT_POINT_FADE_THRESHOLD_SIZE;
mHashNameMap[HASH_ELEMENT_POINT_SIZE] = NAME_ELEMENT_POINT_SIZE;
mHashNameMap[HASH_ELEMENT_POINT_SIZE_MAX] = NAME_ELEMENT_POINT_SIZE_MAX;
mHashNameMap[HASH_ELEMENT_POINT_SIZE_MIN] = NAME_ELEMENT_POINT_SIZE_MIN;
mHashNameMap[HASH_ELEMENT_POINT_SMOOTH_ENABLE] = NAME_ELEMENT_POINT_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYGONS] = NAME_ELEMENT_POLYGONS;
mHashNameMap[HASH_ELEMENT_POLYGON_MODE] = NAME_ELEMENT_POLYGON_MODE;
mHashNameMap[HASH_ELEMENT_POLYGON_MODE__FACE] = NAME_ELEMENT_POLYGON_MODE__FACE;
mHashNameMap[HASH_ELEMENT_POLYGON_MODE__MODE] = NAME_ELEMENT_POLYGON_MODE__MODE;
mHashNameMap[HASH_ELEMENT_POLYGON_OFFSET] = NAME_ELEMENT_POLYGON_OFFSET;
mHashNameMap[HASH_ELEMENT_POLYGON_OFFSET_FILL_ENABLE] = NAME_ELEMENT_POLYGON_OFFSET_FILL_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYGON_OFFSET_LINE_ENABLE] = NAME_ELEMENT_POLYGON_OFFSET_LINE_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYGON_OFFSET_POINT_ENABLE] = NAME_ELEMENT_POLYGON_OFFSET_POINT_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYGON_SMOOTH_ENABLE] = NAME_ELEMENT_POLYGON_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYGON_STIPPLE_ENABLE] = NAME_ELEMENT_POLYGON_STIPPLE_ENABLE;
mHashNameMap[HASH_ELEMENT_POLYLIST] = NAME_ELEMENT_POLYLIST;
mHashNameMap[HASH_ELEMENT_PRECISION] = NAME_ELEMENT_PRECISION;
mHashNameMap[HASH_ELEMENT_PRIMARY] = NAME_ELEMENT_PRIMARY;
mHashNameMap[HASH_ELEMENT_PROFILE_CG] = NAME_ELEMENT_PROFILE_CG;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__NEWPARAM__SURFACE__GENERATOR__NAME] = NAME_ELEMENT_PROFILE_CG__NEWPARAM__SURFACE__GENERATOR__NAME;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__BIND] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__BIND;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__BIND__PARAM] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__BIND__PARAM;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__COMPILER_TARGET] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__COMPILER_TARGET;
mHashNameMap[HASH_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__NAME] = NAME_ELEMENT_PROFILE_CG__TECHNIQUE__PASS__SHADER__NAME;
mHashNameMap[HASH_ELEMENT_PROFILE_COMMON] = NAME_ELEMENT_PROFILE_COMMON;
mHashNameMap[HASH_ELEMENT_PROFILE_COMMON__TECHNIQUE] = NAME_ELEMENT_PROFILE_COMMON__TECHNIQUE;
mHashNameMap[HASH_ELEMENT_PROFILE_COMMON__TECHNIQUE__CONSTANT] = NAME_ELEMENT_PROFILE_COMMON__TECHNIQUE__CONSTANT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES] = NAME_ELEMENT_PROFILE_GLES;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC__FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC__FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC__VALUE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_FUNC__VALUE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__ALPHA_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC__DEST] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC__DEST;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC__SRC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__BLEND_FUNC__SRC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_COLOR] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_COLOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_DEPTH] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_DEPTH;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_STENCIL] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLEAR_STENCIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLIP_PLANE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLIP_PLANE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLIP_PLANE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CLIP_PLANE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_LOGIC_OP_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_LOGIC_OP_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_MASK] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_MATERIAL_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__COLOR_MATERIAL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CULL_FACE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CULL_FACE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CULL_FACE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__CULL_FACE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_MASK] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_RANGE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_RANGE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DEPTH_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DITHER_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__DITHER_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_COLOR] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_COLOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_DENSITY] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_DENSITY;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_END] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_END;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_MODE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_MODE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_START] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FOG_START;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FRONT_FACE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__FRONT_FACE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHTING_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHTING_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_AMBIENT] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_CONSTANT_ATTENUATION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_CONSTANT_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_DIFFUSE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_DIFFUSE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_MODEL_AMBIENT] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_MODEL_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_MODEL_TWO_SIDE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_MODEL_TWO_SIDE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_POSITION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_POSITION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_QUADRATIC_ATTENUATION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_QUADRATIC_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPECULAR] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPECULAR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_CUTOFF] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_CUTOFF;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_DIRECTION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_DIRECTION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_EXPONENT] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LIGHT_SPOT_EXPONENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LINE_SMOOTH_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LINE_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LINE_WIDTH] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LINE_WIDTH;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LOGIC_OP] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__LOGIC_OP;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_AMBIENT] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_DIFFUSE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_DIFFUSE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_EMISSION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_EMISSION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_SHININESS] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_SHININESS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_SPECULAR] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MATERIAL_SPECULAR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MODEL_VIEW_MATRIX] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MODEL_VIEW_MATRIX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MULTISAMPLE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__MULTISAMPLE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__NORMALIZE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__NORMALIZE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_DISTANCE_ATTENUATION] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_DISTANCE_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_FADE_THRESHOLD_SIZE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_FADE_THRESHOLD_SIZE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE_MAX] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE_MAX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE_MIN] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SIZE_MIN;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SMOOTH_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POINT_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POLYGON_OFFSET] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POLYGON_OFFSET;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POLYGON_OFFSET_FILL_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__POLYGON_OFFSET_FILL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__PROJECTION_MATRIX] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__PROJECTION_MATRIX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__RESCALE_NORMAL_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__RESCALE_NORMAL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_COVERAGE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_ONE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_ONE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_COVERAGE_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SAMPLE_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SCISSOR] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SCISSOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SCISSOR_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SCISSOR_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SHADE_MODEL] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__SHADE_MODEL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__FUNC] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__MASK] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__REF] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_FUNC__REF;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_MASK] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__FAIL] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__FAIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__ZFAIL] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__ZFAIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__ZPASS] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_OP__ZPASS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__STENCIL_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__TEXTURE_PIPELINE] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__PASS__TEXTURE_PIPELINE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLES__TECHNIQUE__SETPARAM] = NAME_ELEMENT_PROFILE_GLES__TECHNIQUE__SETPARAM;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL] = NAME_ELEMENT_PROFILE_GLSL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__NEWPARAM__SURFACE__GENERATOR__NAME] = NAME_ELEMENT_PROFILE_GLSL__NEWPARAM__SURFACE__GENERATOR__NAME;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC__FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC__FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC__VALUE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_FUNC__VALUE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__ALPHA_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC__DEST] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC__DEST;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC__SRC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__BLEND_FUNC__SRC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_COLOR] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_COLOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_DEPTH] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_DEPTH;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_STENCIL] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLEAR_STENCIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLIP_PLANE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLIP_PLANE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLIP_PLANE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CLIP_PLANE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_LOGIC_OP_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_LOGIC_OP_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_MASK] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_MATERIAL_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__COLOR_MATERIAL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CULL_FACE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CULL_FACE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CULL_FACE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__CULL_FACE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_MASK] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_RANGE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_RANGE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DEPTH_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DITHER_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__DITHER_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_COLOR] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_COLOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_DENSITY] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_DENSITY;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_END] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_END;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_MODE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_MODE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_START] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FOG_START;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FRONT_FACE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__FRONT_FACE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHTING_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHTING_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_AMBIENT] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_CONSTANT_ATTENUATION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_CONSTANT_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_DIFFUSE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_DIFFUSE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_MODEL_AMBIENT] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_MODEL_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_MODEL_TWO_SIDE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_MODEL_TWO_SIDE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_POSITION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_POSITION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_QUADRATIC_ATTENUATION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_QUADRATIC_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPECULAR] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPECULAR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_CUTOFF] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_CUTOFF;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_DIRECTION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_DIRECTION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_EXPONENT] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LIGHT_SPOT_EXPONENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LINE_SMOOTH_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LINE_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LINE_WIDTH] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LINE_WIDTH;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LOGIC_OP] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__LOGIC_OP;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_AMBIENT] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_AMBIENT;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_DIFFUSE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_DIFFUSE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_EMISSION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_EMISSION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_SHININESS] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_SHININESS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_SPECULAR] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MATERIAL_SPECULAR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MODEL_VIEW_MATRIX] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MODEL_VIEW_MATRIX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MULTISAMPLE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__MULTISAMPLE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__NORMALIZE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__NORMALIZE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_DISTANCE_ATTENUATION] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_DISTANCE_ATTENUATION;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_FADE_THRESHOLD_SIZE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_FADE_THRESHOLD_SIZE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE_MAX] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE_MAX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE_MIN] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SIZE_MIN;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SMOOTH_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POINT_SMOOTH_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POLYGON_OFFSET] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POLYGON_OFFSET;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POLYGON_OFFSET_FILL_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__POLYGON_OFFSET_FILL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__PROJECTION_MATRIX] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__PROJECTION_MATRIX;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__RESCALE_NORMAL_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__RESCALE_NORMAL_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_COVERAGE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_ONE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_ALPHA_TO_ONE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_COVERAGE_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SAMPLE_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SCISSOR] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SCISSOR;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SCISSOR_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SCISSOR_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__BIND] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__BIND;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__BIND__PARAM] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__BIND__PARAM;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__COMPILER_TARGET] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__COMPILER_TARGET;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__NAME] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADER__NAME;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADE_MODEL] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__SHADE_MODEL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__FUNC] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__FUNC;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__MASK] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__REF] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_FUNC__REF;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_MASK] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_MASK;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__FAIL] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__FAIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__ZFAIL] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__ZFAIL;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__ZPASS] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_OP__ZPASS;
mHashNameMap[HASH_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_TEST_ENABLE] = NAME_ELEMENT_PROFILE_GLSL__TECHNIQUE__PASS__STENCIL_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_PROJECTION_MATRIX] = NAME_ELEMENT_PROJECTION_MATRIX;
mHashNameMap[HASH_ELEMENT_QUADRATIC_ATTENUATION] = NAME_ELEMENT_QUADRATIC_ATTENUATION;
mHashNameMap[HASH_ELEMENT_RADIUS] = NAME_ELEMENT_RADIUS;
mHashNameMap[HASH_ELEMENT_RADIUS1] = NAME_ELEMENT_RADIUS1;
mHashNameMap[HASH_ELEMENT_RADIUS2] = NAME_ELEMENT_RADIUS2;
mHashNameMap[HASH_ELEMENT_RADIUS____FLOAT] = NAME_ELEMENT_RADIUS____FLOAT;
mHashNameMap[HASH_ELEMENT_RADIUS____FLOAT2] = NAME_ELEMENT_RADIUS____FLOAT2;
mHashNameMap[HASH_ELEMENT_RANGE] = NAME_ELEMENT_RANGE;
mHashNameMap[HASH_ELEMENT_REF] = NAME_ELEMENT_REF;
mHashNameMap[HASH_ELEMENT_REFLECTIVE] = NAME_ELEMENT_REFLECTIVE;
mHashNameMap[HASH_ELEMENT_REFLECTIVITY] = NAME_ELEMENT_REFLECTIVITY;
mHashNameMap[HASH_ELEMENT_REF_ATTACHMENT] = NAME_ELEMENT_REF_ATTACHMENT;
mHashNameMap[HASH_ELEMENT_RENDER] = NAME_ELEMENT_RENDER;
mHashNameMap[HASH_ELEMENT_RESCALE_NORMAL_ENABLE] = NAME_ELEMENT_RESCALE_NORMAL_ENABLE;
mHashNameMap[HASH_ELEMENT_RESTITUTION] = NAME_ELEMENT_RESTITUTION;
mHashNameMap[HASH_ELEMENT_REVISION] = NAME_ELEMENT_REVISION;
mHashNameMap[HASH_ELEMENT_RGB] = NAME_ELEMENT_RGB;
mHashNameMap[HASH_ELEMENT_RIGID_BODY] = NAME_ELEMENT_RIGID_BODY;
mHashNameMap[HASH_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON] = NAME_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__DYNAMIC] = NAME_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__DYNAMIC;
mHashNameMap[HASH_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__MASS_FRAME] = NAME_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__MASS_FRAME;
mHashNameMap[HASH_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__SHAPE] = NAME_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__SHAPE;
mHashNameMap[HASH_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__SHAPE__HOLLOW] = NAME_ELEMENT_RIGID_BODY__TECHNIQUE_COMMON__SHAPE__HOLLOW;
mHashNameMap[HASH_ELEMENT_RIGID_CONSTRAINT] = NAME_ELEMENT_RIGID_CONSTRAINT;
mHashNameMap[HASH_ELEMENT_RIGID_CONSTRAINT__TECHNIQUE_COMMON] = NAME_ELEMENT_RIGID_CONSTRAINT__TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_ROTATE] = NAME_ELEMENT_ROTATE;
mHashNameMap[HASH_ELEMENT_SAMPLER] = NAME_ELEMENT_SAMPLER;
mHashNameMap[HASH_ELEMENT_SAMPLER1D] = NAME_ELEMENT_SAMPLER1D;
mHashNameMap[HASH_ELEMENT_SAMPLER1D____CG_SAMPLER1D] = NAME_ELEMENT_SAMPLER1D____CG_SAMPLER1D;
mHashNameMap[HASH_ELEMENT_SAMPLER1D____FX_SAMPLER1D_COMMON] = NAME_ELEMENT_SAMPLER1D____FX_SAMPLER1D_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLER1D____GL_SAMPLER1D] = NAME_ELEMENT_SAMPLER1D____GL_SAMPLER1D;
mHashNameMap[HASH_ELEMENT_SAMPLER2D] = NAME_ELEMENT_SAMPLER2D;
mHashNameMap[HASH_ELEMENT_SAMPLER2D____CG_SAMPLER2D] = NAME_ELEMENT_SAMPLER2D____CG_SAMPLER2D;
mHashNameMap[HASH_ELEMENT_SAMPLER2D____FX_SAMPLER2D_COMMON] = NAME_ELEMENT_SAMPLER2D____FX_SAMPLER2D_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLER2D____GL_SAMPLER2D] = NAME_ELEMENT_SAMPLER2D____GL_SAMPLER2D;
mHashNameMap[HASH_ELEMENT_SAMPLER3D] = NAME_ELEMENT_SAMPLER3D;
mHashNameMap[HASH_ELEMENT_SAMPLER3D____CG_SAMPLER3D] = NAME_ELEMENT_SAMPLER3D____CG_SAMPLER3D;
mHashNameMap[HASH_ELEMENT_SAMPLER3D____FX_SAMPLER3D_COMMON] = NAME_ELEMENT_SAMPLER3D____FX_SAMPLER3D_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLER3D____GL_SAMPLER3D] = NAME_ELEMENT_SAMPLER3D____GL_SAMPLER3D;
mHashNameMap[HASH_ELEMENT_SAMPLERCUBE] = NAME_ELEMENT_SAMPLERCUBE;
mHashNameMap[HASH_ELEMENT_SAMPLERCUBE____CG_SAMPLERCUBE] = NAME_ELEMENT_SAMPLERCUBE____CG_SAMPLERCUBE;
mHashNameMap[HASH_ELEMENT_SAMPLERCUBE____FX_SAMPLERCUBE_COMMON] = NAME_ELEMENT_SAMPLERCUBE____FX_SAMPLERCUBE_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLERCUBE____GL_SAMPLERCUBE] = NAME_ELEMENT_SAMPLERCUBE____GL_SAMPLERCUBE;
mHashNameMap[HASH_ELEMENT_SAMPLERDEPTH] = NAME_ELEMENT_SAMPLERDEPTH;
mHashNameMap[HASH_ELEMENT_SAMPLERDEPTH____CG_SAMPLERDEPTH] = NAME_ELEMENT_SAMPLERDEPTH____CG_SAMPLERDEPTH;
mHashNameMap[HASH_ELEMENT_SAMPLERDEPTH____FX_SAMPLERDEPTH_COMMON] = NAME_ELEMENT_SAMPLERDEPTH____FX_SAMPLERDEPTH_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLERDEPTH____GL_SAMPLERDEPTH] = NAME_ELEMENT_SAMPLERDEPTH____GL_SAMPLERDEPTH;
mHashNameMap[HASH_ELEMENT_SAMPLERRECT] = NAME_ELEMENT_SAMPLERRECT;
mHashNameMap[HASH_ELEMENT_SAMPLERRECT____CG_SAMPLERRECT] = NAME_ELEMENT_SAMPLERRECT____CG_SAMPLERRECT;
mHashNameMap[HASH_ELEMENT_SAMPLERRECT____FX_SAMPLERRECT_COMMON] = NAME_ELEMENT_SAMPLERRECT____FX_SAMPLERRECT_COMMON;
mHashNameMap[HASH_ELEMENT_SAMPLERRECT____GL_SAMPLERRECT] = NAME_ELEMENT_SAMPLERRECT____GL_SAMPLERRECT;
mHashNameMap[HASH_ELEMENT_SAMPLER_STATE] = NAME_ELEMENT_SAMPLER_STATE;
mHashNameMap[HASH_ELEMENT_SAMPLER_STATE____GLES_SAMPLER_STATE] = NAME_ELEMENT_SAMPLER_STATE____GLES_SAMPLER_STATE;
mHashNameMap[HASH_ELEMENT_SAMPLER_STATE____NCNAME] = NAME_ELEMENT_SAMPLER_STATE____NCNAME;
mHashNameMap[HASH_ELEMENT_SAMPLE_ALPHA_TO_COVERAGE_ENABLE] = NAME_ELEMENT_SAMPLE_ALPHA_TO_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_SAMPLE_ALPHA_TO_ONE_ENABLE] = NAME_ELEMENT_SAMPLE_ALPHA_TO_ONE_ENABLE;
mHashNameMap[HASH_ELEMENT_SAMPLE_COVERAGE_ENABLE] = NAME_ELEMENT_SAMPLE_COVERAGE_ENABLE;
mHashNameMap[HASH_ELEMENT_SCALE] = NAME_ELEMENT_SCALE;
mHashNameMap[HASH_ELEMENT_SCENE] = NAME_ELEMENT_SCENE;
mHashNameMap[HASH_ELEMENT_SCISSOR] = NAME_ELEMENT_SCISSOR;
mHashNameMap[HASH_ELEMENT_SCISSOR_TEST_ENABLE] = NAME_ELEMENT_SCISSOR_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_SEMANTIC] = NAME_ELEMENT_SEMANTIC;
mHashNameMap[HASH_ELEMENT_SETPARAM] = NAME_ELEMENT_SETPARAM;
mHashNameMap[HASH_ELEMENT_SETPARAM____CG_SETPARAM] = NAME_ELEMENT_SETPARAM____CG_SETPARAM;
mHashNameMap[HASH_ELEMENT_SETPARAM____CG_SETPARAM_SIMPLE] = NAME_ELEMENT_SETPARAM____CG_SETPARAM_SIMPLE;
mHashNameMap[HASH_ELEMENT_SETPARAM____GLSL_SETPARAM] = NAME_ELEMENT_SETPARAM____GLSL_SETPARAM;
mHashNameMap[HASH_ELEMENT_SETPARAM____GLSL_SETPARAM_SIMPLE] = NAME_ELEMENT_SETPARAM____GLSL_SETPARAM_SIMPLE;
mHashNameMap[HASH_ELEMENT_SHADER] = NAME_ELEMENT_SHADER;
mHashNameMap[HASH_ELEMENT_SHADE_MODEL] = NAME_ELEMENT_SHADE_MODEL;
mHashNameMap[HASH_ELEMENT_SHAPE] = NAME_ELEMENT_SHAPE;
mHashNameMap[HASH_ELEMENT_SHININESS] = NAME_ELEMENT_SHININESS;
mHashNameMap[HASH_ELEMENT_SIZE] = NAME_ELEMENT_SIZE;
mHashNameMap[HASH_ELEMENT_SIZE____FLOAT3] = NAME_ELEMENT_SIZE____FLOAT3;
mHashNameMap[HASH_ELEMENT_SIZE____INT3] = NAME_ELEMENT_SIZE____INT3;
mHashNameMap[HASH_ELEMENT_SKELETON] = NAME_ELEMENT_SKELETON;
mHashNameMap[HASH_ELEMENT_SKEW] = NAME_ELEMENT_SKEW;
mHashNameMap[HASH_ELEMENT_SKIN] = NAME_ELEMENT_SKIN;
mHashNameMap[HASH_ELEMENT_SOURCE] = NAME_ELEMENT_SOURCE;
mHashNameMap[HASH_ELEMENT_SOURCE_DATA] = NAME_ELEMENT_SOURCE_DATA;
mHashNameMap[HASH_ELEMENT_SOURCE____NCNAME] = NAME_ELEMENT_SOURCE____NCNAME;
mHashNameMap[HASH_ELEMENT_SPECULAR] = NAME_ELEMENT_SPECULAR;
mHashNameMap[HASH_ELEMENT_SPHERE] = NAME_ELEMENT_SPHERE;
mHashNameMap[HASH_ELEMENT_SPLINE] = NAME_ELEMENT_SPLINE;
mHashNameMap[HASH_ELEMENT_SPOT] = NAME_ELEMENT_SPOT;
mHashNameMap[HASH_ELEMENT_SPRING] = NAME_ELEMENT_SPRING;
mHashNameMap[HASH_ELEMENT_SPRING__LINEAR] = NAME_ELEMENT_SPRING__LINEAR;
mHashNameMap[HASH_ELEMENT_SRC] = NAME_ELEMENT_SRC;
mHashNameMap[HASH_ELEMENT_SRC_ALPHA] = NAME_ELEMENT_SRC_ALPHA;
mHashNameMap[HASH_ELEMENT_SRC_RGB] = NAME_ELEMENT_SRC_RGB;
mHashNameMap[HASH_ELEMENT_STATIC_FRICTION] = NAME_ELEMENT_STATIC_FRICTION;
mHashNameMap[HASH_ELEMENT_STENCIL_CLEAR] = NAME_ELEMENT_STENCIL_CLEAR;
mHashNameMap[HASH_ELEMENT_STENCIL_CLEAR____BYTE] = NAME_ELEMENT_STENCIL_CLEAR____BYTE;
mHashNameMap[HASH_ELEMENT_STENCIL_CLEAR____FX_CLEARSTENCIL_COMMON] = NAME_ELEMENT_STENCIL_CLEAR____FX_CLEARSTENCIL_COMMON;
mHashNameMap[HASH_ELEMENT_STENCIL_FUNC] = NAME_ELEMENT_STENCIL_FUNC;
mHashNameMap[HASH_ELEMENT_STENCIL_FUNC_SEPARATE] = NAME_ELEMENT_STENCIL_FUNC_SEPARATE;
mHashNameMap[HASH_ELEMENT_STENCIL_FUNC_SEPARATE__MASK] = NAME_ELEMENT_STENCIL_FUNC_SEPARATE__MASK;
mHashNameMap[HASH_ELEMENT_STENCIL_FUNC_SEPARATE__REF] = NAME_ELEMENT_STENCIL_FUNC_SEPARATE__REF;
mHashNameMap[HASH_ELEMENT_STENCIL_MASK] = NAME_ELEMENT_STENCIL_MASK;
mHashNameMap[HASH_ELEMENT_STENCIL_MASK_SEPARATE] = NAME_ELEMENT_STENCIL_MASK_SEPARATE;
mHashNameMap[HASH_ELEMENT_STENCIL_MASK_SEPARATE__FACE] = NAME_ELEMENT_STENCIL_MASK_SEPARATE__FACE;
mHashNameMap[HASH_ELEMENT_STENCIL_MASK_SEPARATE__MASK] = NAME_ELEMENT_STENCIL_MASK_SEPARATE__MASK;
mHashNameMap[HASH_ELEMENT_STENCIL_OP] = NAME_ELEMENT_STENCIL_OP;
mHashNameMap[HASH_ELEMENT_STENCIL_OP_SEPARATE] = NAME_ELEMENT_STENCIL_OP_SEPARATE;
mHashNameMap[HASH_ELEMENT_STENCIL_OP_SEPARATE__FACE] = NAME_ELEMENT_STENCIL_OP_SEPARATE__FACE;
mHashNameMap[HASH_ELEMENT_STENCIL_OP_SEPARATE__FAIL] = NAME_ELEMENT_STENCIL_OP_SEPARATE__FAIL;
mHashNameMap[HASH_ELEMENT_STENCIL_OP_SEPARATE__ZFAIL] = NAME_ELEMENT_STENCIL_OP_SEPARATE__ZFAIL;
mHashNameMap[HASH_ELEMENT_STENCIL_OP_SEPARATE__ZPASS] = NAME_ELEMENT_STENCIL_OP_SEPARATE__ZPASS;
mHashNameMap[HASH_ELEMENT_STENCIL_TARGET] = NAME_ELEMENT_STENCIL_TARGET;
mHashNameMap[HASH_ELEMENT_STENCIL_TARGET____FX_STENCILTARGET_COMMON] = NAME_ELEMENT_STENCIL_TARGET____FX_STENCILTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_STENCIL_TARGET____GLES_RENDERTARGET_COMMON] = NAME_ELEMENT_STENCIL_TARGET____GLES_RENDERTARGET_COMMON;
mHashNameMap[HASH_ELEMENT_STENCIL_TEST_ENABLE] = NAME_ELEMENT_STENCIL_TEST_ENABLE;
mHashNameMap[HASH_ELEMENT_STIFFNESS] = NAME_ELEMENT_STIFFNESS;
mHashNameMap[HASH_ELEMENT_STRING] = NAME_ELEMENT_STRING;
mHashNameMap[HASH_ELEMENT_SUBJECT] = NAME_ELEMENT_SUBJECT;
mHashNameMap[HASH_ELEMENT_SURFACE] = NAME_ELEMENT_SURFACE;
mHashNameMap[HASH_ELEMENT_SURFACE____CG_SURFACE_TYPE] = NAME_ELEMENT_SURFACE____CG_SURFACE_TYPE;
mHashNameMap[HASH_ELEMENT_SURFACE____FX_SURFACE_COMMON] = NAME_ELEMENT_SURFACE____FX_SURFACE_COMMON;
mHashNameMap[HASH_ELEMENT_SURFACE____GLSL_SURFACE_TYPE] = NAME_ELEMENT_SURFACE____GLSL_SURFACE_TYPE;
mHashNameMap[HASH_ELEMENT_SURFACE____NCNAME] = NAME_ELEMENT_SURFACE____NCNAME;
mHashNameMap[HASH_ELEMENT_SWING_CONE_AND_TWIST] = NAME_ELEMENT_SWING_CONE_AND_TWIST;
mHashNameMap[HASH_ELEMENT_TAPERED_CAPSULE] = NAME_ELEMENT_TAPERED_CAPSULE;
mHashNameMap[HASH_ELEMENT_TAPERED_CYLINDER] = NAME_ELEMENT_TAPERED_CYLINDER;
mHashNameMap[HASH_ELEMENT_TARGETS] = NAME_ELEMENT_TARGETS;
mHashNameMap[HASH_ELEMENT_TARGET_VALUE] = NAME_ELEMENT_TARGET_VALUE;
mHashNameMap[HASH_ELEMENT_TECHNIQUE] = NAME_ELEMENT_TECHNIQUE;
mHashNameMap[HASH_ELEMENT_TECHNIQUE_COMMON] = NAME_ELEMENT_TECHNIQUE_COMMON;
mHashNameMap[HASH_ELEMENT_TECHNIQUE_HINT] = NAME_ELEMENT_TECHNIQUE_HINT;
mHashNameMap[HASH_ELEMENT_TEXCOMBINER] = NAME_ELEMENT_TEXCOMBINER;
mHashNameMap[HASH_ELEMENT_TEXCOORD] = NAME_ELEMENT_TEXCOORD;
mHashNameMap[HASH_ELEMENT_TEXENV] = NAME_ELEMENT_TEXENV;
mHashNameMap[HASH_ELEMENT_TEXTURE] = NAME_ELEMENT_TEXTURE;
mHashNameMap[HASH_ELEMENT_TEXTURE1D] = NAME_ELEMENT_TEXTURE1D;
mHashNameMap[HASH_ELEMENT_TEXTURE1D_ENABLE] = NAME_ELEMENT_TEXTURE1D_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURE2D] = NAME_ELEMENT_TEXTURE2D;
mHashNameMap[HASH_ELEMENT_TEXTURE2D_ENABLE] = NAME_ELEMENT_TEXTURE2D_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURE3D] = NAME_ELEMENT_TEXTURE3D;
mHashNameMap[HASH_ELEMENT_TEXTURE3D_ENABLE] = NAME_ELEMENT_TEXTURE3D_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURECUBE] = NAME_ELEMENT_TEXTURECUBE;
mHashNameMap[HASH_ELEMENT_TEXTURECUBE_ENABLE] = NAME_ELEMENT_TEXTURECUBE_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTUREDEPTH] = NAME_ELEMENT_TEXTUREDEPTH;
mHashNameMap[HASH_ELEMENT_TEXTUREDEPTH_ENABLE] = NAME_ELEMENT_TEXTUREDEPTH_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURERECT] = NAME_ELEMENT_TEXTURERECT;
mHashNameMap[HASH_ELEMENT_TEXTURERECT_ENABLE] = NAME_ELEMENT_TEXTURERECT_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURE_ENV_COLOR] = NAME_ELEMENT_TEXTURE_ENV_COLOR;
mHashNameMap[HASH_ELEMENT_TEXTURE_ENV_MODE] = NAME_ELEMENT_TEXTURE_ENV_MODE;
mHashNameMap[HASH_ELEMENT_TEXTURE_PIPELINE] = NAME_ELEMENT_TEXTURE_PIPELINE;
mHashNameMap[HASH_ELEMENT_TEXTURE_PIPELINE_ENABLE] = NAME_ELEMENT_TEXTURE_PIPELINE_ENABLE;
mHashNameMap[HASH_ELEMENT_TEXTURE_PIPELINE____GLES_TEXTURE_PIPELINE] = NAME_ELEMENT_TEXTURE_PIPELINE____GLES_TEXTURE_PIPELINE;
mHashNameMap[HASH_ELEMENT_TEXTURE_UNIT] = NAME_ELEMENT_TEXTURE_UNIT;
mHashNameMap[HASH_ELEMENT_TIME_STEP] = NAME_ELEMENT_TIME_STEP;
mHashNameMap[HASH_ELEMENT_TITLE] = NAME_ELEMENT_TITLE;
mHashNameMap[HASH_ELEMENT_TRANSLATE] = NAME_ELEMENT_TRANSLATE;
mHashNameMap[HASH_ELEMENT_TRANSPARENCY] = NAME_ELEMENT_TRANSPARENCY;
mHashNameMap[HASH_ELEMENT_TRANSPARENT] = NAME_ELEMENT_TRANSPARENT;
mHashNameMap[HASH_ELEMENT_TRIANGLES] = NAME_ELEMENT_TRIANGLES;
mHashNameMap[HASH_ELEMENT_TRIFANS] = NAME_ELEMENT_TRIFANS;
mHashNameMap[HASH_ELEMENT_TRISTRIPS] = NAME_ELEMENT_TRISTRIPS;
mHashNameMap[HASH_ELEMENT_UNIT] = NAME_ELEMENT_UNIT;
mHashNameMap[HASH_ELEMENT_UP_AXIS] = NAME_ELEMENT_UP_AXIS;
mHashNameMap[HASH_ELEMENT_USERTYPE] = NAME_ELEMENT_USERTYPE;
mHashNameMap[HASH_ELEMENT_V] = NAME_ELEMENT_V;
mHashNameMap[HASH_ELEMENT_VALUE] = NAME_ELEMENT_VALUE;
mHashNameMap[HASH_ELEMENT_VALUE____GLES_TEXTURE_PIPELINE] = NAME_ELEMENT_VALUE____GLES_TEXTURE_PIPELINE;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLER1D] = NAME_ELEMENT_VALUE____GL_SAMPLER1D;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLER2D] = NAME_ELEMENT_VALUE____GL_SAMPLER2D;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLER3D] = NAME_ELEMENT_VALUE____GL_SAMPLER3D;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLERCUBE] = NAME_ELEMENT_VALUE____GL_SAMPLERCUBE;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLERDEPTH] = NAME_ELEMENT_VALUE____GL_SAMPLERDEPTH;
mHashNameMap[HASH_ELEMENT_VALUE____GL_SAMPLERRECT] = NAME_ELEMENT_VALUE____GL_SAMPLERRECT;
mHashNameMap[HASH_ELEMENT_VCOUNT] = NAME_ELEMENT_VCOUNT;
mHashNameMap[HASH_ELEMENT_VELOCITY] = NAME_ELEMENT_VELOCITY;
mHashNameMap[HASH_ELEMENT_VERTEX_WEIGHTS] = NAME_ELEMENT_VERTEX_WEIGHTS;
mHashNameMap[HASH_ELEMENT_VERTICES] = NAME_ELEMENT_VERTICES;
mHashNameMap[HASH_ELEMENT_VIEWPORT_RATIO] = NAME_ELEMENT_VIEWPORT_RATIO;
mHashNameMap[HASH_ELEMENT_VISUAL_SCENE] = NAME_ELEMENT_VISUAL_SCENE;
mHashNameMap[HASH_ELEMENT_WRAP_P] = NAME_ELEMENT_WRAP_P;
mHashNameMap[HASH_ELEMENT_WRAP_S] = NAME_ELEMENT_WRAP_S;
mHashNameMap[HASH_ELEMENT_WRAP_S____FX_SAMPLER_WRAP_COMMON] = NAME_ELEMENT_WRAP_S____FX_SAMPLER_WRAP_COMMON;
mHashNameMap[HASH_ELEMENT_WRAP_S____GLES_SAMPLER_WRAP] = NAME_ELEMENT_WRAP_S____GLES_SAMPLER_WRAP;
mHashNameMap[HASH_ELEMENT_WRAP_T] = NAME_ELEMENT_WRAP_T;
mHashNameMap[HASH_ELEMENT_WRAP_T____FX_SAMPLER_WRAP_COMMON] = NAME_ELEMENT_WRAP_T____FX_SAMPLER_WRAP_COMMON;
mHashNameMap[HASH_ELEMENT_WRAP_T____GLES_SAMPLER_WRAP] = NAME_ELEMENT_WRAP_T____GLES_SAMPLER_WRAP;
mHashNameMap[HASH_ELEMENT_XFOV] = NAME_ELEMENT_XFOV;
mHashNameMap[HASH_ELEMENT_XMAG] = NAME_ELEMENT_XMAG;
mHashNameMap[HASH_ELEMENT_YFOV] = NAME_ELEMENT_YFOV;
mHashNameMap[HASH_ELEMENT_YMAG] = NAME_ELEMENT_YMAG;
mHashNameMap[HASH_ELEMENT_ZFAIL] = NAME_ELEMENT_ZFAIL;
mHashNameMap[HASH_ELEMENT_ZFAR] = NAME_ELEMENT_ZFAR;
mHashNameMap[HASH_ELEMENT_ZNEAR] = NAME_ELEMENT_ZNEAR;
mHashNameMap[HASH_ELEMENT_ZPASS] = NAME_ELEMENT_ZPASS;
}


} // namespace
